<?php

namespace Elementor;

class ThemeDraft_Button_Widget extends Widget_Base {

	public function get_name() {

		return "themedraft_button";
	}

	public function get_title() {
		return __( "Button", "themedraft-core" );
	}

	public function get_icon() {

		return "eicon-button";
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {
		//Content tab start
		$this->start_controls_section(
			'button_1_content',
			[
				'label' => __( 'Button One', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'button_1_text',
			[
				'label'   => esc_html__( 'Button Text', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => esc_html__( 'Button Text', 'themedraft-core' ),
                'label_block' => true,
			]
		);

		$this->add_control(
			'btn_1_url',
			[
				'label'         => __( 'Button URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'button_2_content',
			[
				'label' => __( 'Button Two', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'button_2_text',
			[
				'label'   => esc_html__( 'Button Text', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'label_block' => true,
			]
		);

		$this->add_control(
			'btn_2_url',
			[
				'label'         => __( 'Button URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);
		$this->end_controls_section();

		// Button Style
		$this->start_controls_section(
		    'btn_1_style',
		    [
		        'label' => esc_html__( 'Button One', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'btn_1_typography',
		        'label' => __( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td_button.td_el_btn_one',
		    ]
		);

		$this->start_controls_tabs('td_button_1_style_tabs');

		//Default style start
		$this->start_controls_tab(
		    'td_btn_1_normal',
		    [
		        'label' => esc_html__('Normal', 'themedraft-core'),
		    ]
		);

		$this->add_control(
		    'button_1_normal_bg',
		    [
		        'label'     => esc_html__('Background Color', 'themedraft-core'),
		        'type'      => Controls_Manager::COLOR,
		        'selectors' => [
		            '{{WRAPPER}} .td_button.td_el_btn_one' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'button_1_normal_text_color',
		    [
		        'label'       => esc_html__('Text Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td_button.td_el_btn_one' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_1_normal_border',
				'label' => esc_html__('Border', 'themedraft-core'),
				'selector' => '{{WRAPPER}} .td_button.td_el_btn_one',
			]
		);
		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
		    'td_btn_1_style_hover',
		    [
		        'label' => esc_html__('Hover', 'themedraft-core'),
		    ]
		);

		$this->add_control(
			'button_1_hover_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_el_btn_one:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_1_hover_text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td_button.td_el_btn_one:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_1_hover_border',
				'label' => esc_html__('Border', 'themedraft-core'),
				'selector' => '{{WRAPPER}} .td_button.td_el_btn_one:hover',
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();



		// Button 2 Style
		$this->start_controls_section(
			'btn_2_style',
			[
				'label' => esc_html__( 'Button Two', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
				'condition' => [
					'button_2_text!' => '',
				]
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'btn_2_typography',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td_button.td_el_btn_two',
			]
		);

		$this->start_controls_tabs('td_button_2_style_tabs');

		//Default style start
		$this->start_controls_tab(
			'td_btn_2_normal',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_2_normal_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_el_btn_two' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_2_normal_text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td_button.td_el_btn_two' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_2_normal_border',
				'label' => esc_html__('Border', 'themedraft-core'),
				'selector' => '{{WRAPPER}} .td_button.td_el_btn_two',
			]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'td_btn_2_style_hover',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_2_hover_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_el_btn_two:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_2_hover_text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td_button.td_el_btn_two:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'button_2_hover_border',
				'label' => esc_html__('Border', 'themedraft-core'),
				'selector' => '{{WRAPPER}} .td_button.td_el_btn_two:hover',
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();

		$this->start_controls_section(
		    'btn_other_style',
		    [
		        'label' => esc_html__( 'Others', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
		    'button_align',
		    [
		        'label'       => esc_html__('Button Align', 'themedraft-core'),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options' => [
		            'left' => [
		                'title' => __('Left', 'themedraft-core'),
		                'icon'  => 'fa fa-align-left',
		            ],

		            'center' => [
		                'title' => __('Center', 'themedraft-core'),
		                'icon'  => 'fa fa-align-center',
		            ],

		            'right' => [
		                'title' => __('Right', 'themedraft-core'),
		                'icon'  => 'fa fa-align-right',
		            ],
		        ],

		        'default' => 'left',
		        'devices' => ['desktop', 'tablet', 'mobile'],

		        'selectors' => [
		            '{{WRAPPER}} .td-button-el-widget' => 'text-align: {{VALUE}};',
		        ],

		    ]
		);

		$this->add_responsive_control(
		    'button_padding',
		    [
		        'label'      => esc_html__( 'Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td_button.td_el_btn_one,{{WRAPPER}} .td_button.td_el_btn_two' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_control(
			'button_border_radius',
			[
				'label' => __( 'Border Radius', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .td_button.td_el_btn_one,{{WRAPPER}} .td_button.td_el_btn_two' => 'border-radius: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}


	//Render In HTML
	protected function render() {
		$settings = $this->get_settings_for_display();
		$btn_one_target   = $settings['btn_1_url']['is_external'] ? ' target="_blank"' : '';
		$btn_one_nofollow = $settings['btn_1_url']['nofollow'] ? ' rel="nofollow"' : '';

		$btn_two_target   = $settings['btn_2_url']['is_external'] ? ' target="_blank"' : '';
		$btn_two_nofollow = $settings['btn_2_url']['nofollow'] ? ' rel="nofollow"' : '';

		?>
        <div class="td-button-el-widget">
            <a href="<?php echo esc_url($settings['btn_1_url']['url']);?>" class="td_button td_el_btn_one" <?php echo $btn_one_target . $btn_one_nofollow ;?>><?php echo esc_html($settings['button_1_text']);?></a>

            <?php if($settings['button_2_text']) : ?>
            <a href="<?php echo esc_url($settings['btn_2_url']['url']);?>" class="td_button td_el_btn_two" <?php echo $btn_two_target . $btn_two_nofollow ;?>><?php echo esc_html($settings['button_2_text']);?></a>
            <?php endif; ?>
        </div>

		<?php
	}

	protected function content_template() {
		?>
        <div class="td-button-el-widget">
            <a href="{{settings.btn_1_url.url}}" class="td_button td_el_btn_one">{{settings.button_1_text}}</a>

            <# if(settings.button_2_text){ #>
            <a href="{{settings.btn_2_url.url}}" class="td_button td_el_btn_two">{{settings.button_2_text}}</a>
            <# } #>
        </div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Button_Widget );