<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

class ThemeDraft_ContactForm7_Widget extends Widget_Base {

	public function get_name() {
		return 'themedraft_contact_form_seven';
	}

	public function get_title() {
		return __( 'Contact Form7', 'themedraft-core' );
	}

	public function get_icon() {
		return 'eicon-mail';
	}
	public function get_categories() {
		return array( 'valkuta_elements' );
	}


	protected function register_controls() {

	    $this->start_controls_section(
	        'form_title_and_subtitle_options',
	        [
	            'label' => esc_html__( 'Form Title', 'themedraft-core' ),
	            'tab'   => Controls_Manager::TAB_CONTENT,
	        ]
	    );

	    $this->add_control(
	        'enable_form_title',
	        [
	            'label'     => esc_html__( 'Enable Form Title', 'themedraft-core' ),
	            'type'      => Controls_Manager::SWITCHER,
	            'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
	            'label_off' => esc_html__( 'No', 'themedraft-core' ),
	            'default'   => 'no',
	        ]
	    );

		$this->add_control(
			'subtitle',
			[
				'label'       => esc_html__( 'Form Subtitle', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'row'         => 4,
				'default'     => esc_html__( 'Contact Us', 'themedraft-core' ),
				'placeholder' => esc_html__( 'Type subtitle here', 'themedraft-core' ),
                'condition' => [
                    'enable_form_title' => 'yes',
                ],
			]
		);

		$this->add_control(
			'subtitle_tag',
			[
				'label'       => esc_html__( 'Subtitle Tag', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,

				'options' => [
					'h1' => esc_html__( 'H1', 'themedraft-core' ),
					'h2' => esc_html__( 'H2', 'themedraft-core' ),
					'h3' => esc_html__( 'H3', 'themedraft-core' ),
					'h4' => esc_html__( 'H4', 'themedraft-core' ),
					'h5' => esc_html__( 'H5', 'themedraft-core' ),
					'h6' => esc_html__( 'H6', 'themedraft-core' ),
				],

				'default'   => 'h6',
				'condition' => [
					'subtitle!' => '',
					'enable_form_title' => 'yes',
				],
			]
		);

		$this->add_control(
			'line_image',
			[
				'label'       => __( 'Line Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => THEMEDRAFT_CORE_ASSETS . 'images/shape-blue.png',
				],

				'condition' => [
					'subtitle!' => '',
					'enable_form_title' => 'yes',
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => esc_html__( 'Get In Touch.', 'themedraft-core' ),
				'placeholder' => esc_html__( 'Type section title here', 'themedraft-core' ),
				'condition' => [
					'enable_form_title' => 'yes',
				],
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,

				'options' => [
					'h1' => esc_html__( 'H1', 'themedraft-core' ),
					'h2' => esc_html__( 'H2', 'themedraft-core' ),
					'h3' => esc_html__( 'H3', 'themedraft-core' ),
					'h4' => esc_html__( 'H4', 'themedraft-core' ),
					'h5' => esc_html__( 'H5', 'themedraft-core' ),
					'h6' => esc_html__( 'H6', 'themedraft-core' ),
				],

				'default' => 'h2',

				'condition' => [
					'title!' => '',
					'enable_form_title' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label'       => esc_html__( 'Text Align', 'themedraft-core' ),
				'description' => esc_html__( '', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,

				'options' => [
					'left' => [
						'title' => __( 'Left', 'themedraft-core' ),
						'icon'  => 'fa fa-align-left',
					],

					'center' => [
						'title' => __( 'Center', 'themedraft-core' ),
						'icon'  => 'fa fa-align-center',
					],

					'right' => [
						'title' => __( 'Right', 'themedraft-core' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-section-title-wrap' => 'text-align: {{VALUE}};',
				],

				'condition' => [
					'enable_form_title' => 'yes',
				],

			]
		);

	    $this->end_controls_section();

		$this->start_controls_section(
			'contact_form_accordion',
			[
				'label' => __( 'Contact Form', 'themedraft-core' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
		
		$this->add_control(
			'wpcf7_form_list',
			[
				'label' => __( 'Select Contact Form', 'themedraft-core' ),
				'label_block' => false,
				'type' => Controls_Manager::SELECT,
				'options' => $this->themedraft_contact_form(),
			]
		);

		$this->add_control(
			'td_extra_css_class',
			[
				'label' => esc_html__( 'Extra Css Classes', 'themedraft-core' ),
				'type' => Controls_Manager::TEXT,
				'description' => esc_html__( 'If you want to use extra css classes type class name here', 'themedraft-core' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'wrapper_options',
		    [
		        'label' => esc_html__( 'Wrapper Options', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'background_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .themedraft-contact-form-container' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'wrapper_padding',
		    [
		        'label'      => esc_html__( 'Wrapper Padding', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .themedraft-contact-form-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'wrapper_border_radius',
		    [
		        'label'      => esc_html__( 'Border Radius', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .themedraft-contact-form-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'themedraft_contact_field_style',
			[
				'label' => __( 'Field Color Options', 'themedraft-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'field_bg_color',
			[
				'label'       => esc_html__('Field Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .themedraft-contact-form-container select' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container input' => 'background-color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container textarea' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'field_border_color',
			[
				'label'       => esc_html__('Field Border Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .themedraft-contact-form-container select' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container input' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container textarea' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'field_border_color_on_focus',
			[
				'label'       => esc_html__('Field Border Color On Focus', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .themedraft-contact-form-container select:focus' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container input:focus' => 'border-color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container textarea:focus' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'field_text_color',
			[
				'label'       => esc_html__('Field Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .themedraft-contact-form-container select' => 'color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container input' => 'color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container textarea' => 'color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container ::placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container :-ms-input-placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container ::-ms-input-placeholder' => 'color: {{VALUE}};',
					'{{WRAPPER}} .themedraft-contact-form-container .select-arrow:before' => 'border-top-color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'themedraft_contact_submit_style',
			[
				'label' => __( 'Submit Button Color Options', 'themedraft-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		//Normal & hover option start
		$this->start_controls_tabs('td_btn_styles');

		//Normal style start
		$this->start_controls_tab(
			'btn_normal_style',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
			'normal_txt_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-contact-form-container input[type="submit"]' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'normal_btn_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-contact-form-container input[type="submit"]' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'normal_background',
				'label' => __( 'Background', 'themedraft-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .themedraft-contact-form-container input[type="submit"]',
			]
		);

		$this->end_controls_tab();
		//Normal style end

		//Hover style start
		$this->start_controls_tab(
			'btn_hover_style',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
			'hover_txt_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-contact-form-container input[type="submit"]:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'hover_btn_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .themedraft-contact-form-container input[type="submit"]:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'hover_bg_color',
				'label' => __( 'Background', 'themedraft-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .themedraft-contact-form-container input[type="submit"]:hover',
			]
		);

		$this->end_controls_tab();
		//Hover style end
		$this->end_controls_tabs();
		//Normal & hover option end

		$this->end_controls_section();

	}

	protected function themedraft_contact_form( ) {

		if ( ! class_exists( 'WPCF7_ContactForm' ) ) {
			return array();
		}

		$forms = \WPCF7_ContactForm::find( array(
			'orderby' => 'title',
			'order'   => 'ASC',
		) );

		if ( empty( $forms ) ) {
			return array();
		}

		$result = array();

		foreach ( $forms as $item ) {
			$key            = sprintf( '%1$s::%2$s', $item->id(), $item->title() );
			$result[ $key ] = $item->title();
		}

		return $result;
	}


	protected function render()  {

		$settings = $this->get_settings();
		$number = rand(100, 10000);
		?>

        <?php if ( ! empty( $settings['wpcf7_form_list'] ) ) { ?>

			<div class="themedraft-contact-form-container <?php echo $settings['td_extra_css_class'];?>">

                <?php if($settings['enable_form_title'] == 'yes') : ?>
                <div class="row">
                    <div class="col-lg-12">
                        <div class="td-section-title-wrap section-title-<?php echo $number ?>">
                            <div class="td-section-title-content">
	                            <?php if ( $settings['subtitle'] ) : ?>
                                <<?php echo $settings['subtitle_tag']; ?> class="subtitle"><?php echo $settings['subtitle']; ?></<?php echo $settings['subtitle_tag']; ?>>
	                            <?php endif; ?>

                                <<?php echo $settings['title_tag']; ?> class="title"><?php echo $settings['title']; ?></<?php echo $settings['title_tag']; ?>>
                            </div>
                        </div>
                    </div>

                    <style>
                        .td-section-title-wrap.section-title-<?php echo $number ?> .subtitle:before{
                            background-image: url("<?php echo $settings['line_image']['url'];?>");
                        }
                    </style>
                </div>

                <?php endif;?>

				<?php echo do_shortcode( '[contact-form-7 id="' . $settings['wpcf7_form_list'] . '" ]' );?>
			</div>

			<?php
		}

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_ContactForm7_Widget );