<?php

namespace Elementor;
class ThemeDraft_CountUp_Widget extends Widget_Base {

	public function get_name() {

		return "themedraft_count_up";
	}

	public function get_title() {
		return "Count Up";
	}

	public function get_icon() {

		return "eicon-counter";
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}

	protected function register_controls() {
		//Start Control Section
		$this->start_controls_section(
			'count_up_options',
			[
				'label' => __( 'Count Up Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'show_icon',
		    [
		        'label'     => esc_html__( 'Show Icon', 'themedraft-core' ),
		        'type'      => Controls_Manager::SWITCHER,
		        'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
		        'label_off' => esc_html__( 'No', 'themedraft-core' ),
		        'default'   => 'yes',
		    ]
		);

		$this->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-info-circle',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
                'condition' => [
                    'show_icon' => 'yes',
                ],
			]
		);

		$this->add_control(
			'selected_icon',
			[
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-pet-veterinary',
					'library' => 'themedraft-pet',
				],
				'conditions' => [
					'terms' => [
						[
							'relation' => 'and',
							'terms' => [
								[
									'name' => 'show_icon',
									'operator' => '==',
									'value' => 'yes',
								],
								[
									'name' => 'type',
									'operator' => '==',
									'value' => 'icon',
								],
							],
						],
					]
				],
			]
		);

		$this->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'conditions' => [
					'terms' => [
						[
							'relation' => 'and',
							'terms' => [
								[
									'name' => 'show_icon',
									'operator' => '==',
									'value' => 'yes',
								],
								[
									'name' => 'type',
									'operator' => '==',
									'value' => 'image',
								],
							],
						],
					]
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$this->add_control(
			'count_number',
			[
				'label'   => __( 'Count Number', 'themedraft-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => __( '100', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'count_unit',
			[
				'label'   => __( 'Counter Unit', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( '+', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'count_title',
			[
				'label'       => __( 'Count Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Counter Title', 'themedraft-core' ),
				'label_block' => true,
			]
		);



		$this->end_controls_section();//End Control Section


		//Start Control Section

		$this->start_controls_section(
			'themeDraft_countup_box_style',
			[
				'label' => __( 'Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'count_background',
				'label' => __( 'Background', 'themedraft-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .td-single-countup-box',
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label' => esc_html__( 'Text Align', 'themedraft-core' ),
				'type'  => Controls_Manager::CHOOSE,

				'options' => [
					'left' => [
						'title' => __( 'Left', 'themedraft-core' ),
						'icon'  => 'fa fa-align-left',
					],

					'center' => [
						'title' => __( 'Center', 'themedraft-core' ),
						'icon'  => 'fa fa-align-center',
					],

					'right' => [
						'title' => __( 'Right', 'themedraft-core' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-countup-content' => 'text-align: {{VALUE}};',
				],

			]
		);

		$this->add_responsive_control(
			'count_box_padding',
			[
				'label'      => esc_html__( 'Box Padding', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-single-countup-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'themeDraft_countup_icon_style',
			[
				'label' => __( 'Icon', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_icon' => 'yes',
                ],
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-countup-content i'   => 'color: {{VALUE}};',
					'{{WRAPPER}} .td-countup-content svg' => 'fill: {{VALUE}};',
				],

				'conditions' => [
					'terms' => [
						[
							'relation' => 'and',
							'terms' => [
								[
									'name' => 'show_icon',
									'operator' => '==',
									'value' => 'yes',
								],
								[
									'name' => 'type',
									'operator' => '==',
									'value' => 'icon',
								],
							],
						],
					]
				],
			]
		);

		$this->add_responsive_control(
		    'icon_size',
		    [
		        'label' => __( 'Size', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 0,
		                'max' => 100,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],
		        'selectors' => [
		            '{{WRAPPER}} .td-count-icon' => 'font-size: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
		    'icon_margin',
		    [
		        'label'      => esc_html__( 'Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-count-icon' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'themeDraft_countup_number_style',
			[
				'label' => __( 'Number', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'number_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-count-number, {{WRAPPER}} .td-count-unit',
			]
		);

		$this->add_control(
			'numb_color',
			[
				'label'     => __( 'Number Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-count-number, {{WRAPPER}} .td-count-unit' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'themeDraft_countup_text_style',
			[
				'label' => __( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-count-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => __( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-count-title' => 'color: {{VALUE}}',
				],
			]
		);

		$this->end_controls_section();//End Control Section
	}

	//Render In HTML
	protected function render() {
		$settings = $this->get_settings_for_display(); ?>
		<div class="td-single-countup-box">
			<div class="td-countup-content">
                <?php if($settings['show_icon'] == 'yes') : ?>

				<div class="td-count-icon">
					<?php if ( $settings['type'] === 'image' ) :
						if ( $settings['image']['url'] || $settings['image']['id'] ) :
							?>
							<img src="<?php echo $settings['image']['url']; ?>"
							     alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">
						<?php endif;
					elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon'] ) ) : ?>

						<?php ThemeDraft_Custom_Icon_Render( $settings, 'icon', 'selected_icon' ); ?>
					<?php endif; ?>
				</div>
                <?php endif; ?>
				<div class="td-number-unit">
					<h6 class="td-count-number"><?php echo esc_html( $settings['count_number'] ) ?></h6>
					<h6 class="td-count-unit"><?php echo esc_html( $settings['count_unit'] ) ?></h6>
				</div>
				<?php if ( $settings['count_title'] ) : ?>
					<p class="td-count-title"><?php echo esc_html( $settings['count_title'] ) ?></p>
				<?php endif; ?>
			</div>
		</div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_CountUp_Widget );