<?php
namespace Elementor;

class ThemeDraft_Home_Slider_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_home_slider';
	}

	public function get_title() {
		return esc_html__( 'Home Slider', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-slider-push';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'slider_content',
			[
				'label' => esc_html__( 'Add Slides', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'slide_subtitle',
			[
				'label'       => esc_html__( 'Slide Subtitle', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => esc_html__( 'Referring the world, and changed the defination of love.', 'themedraft-core' ),
				'description' => __( 'Type slide subtitle here', 'themedraft-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'subtitle_tag',
			[
				'label'   => __( 'Subtitle Tag', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'h6',
				'options' => [
					'h1' => __( 'H1', 'themedraft-core' ),
					'h2' => __( 'H2', 'themedraft-core' ),
					'h3' => __( 'H3', 'themedraft-core' ),
					'h4' => __( 'H4', 'themedraft-core' ),
					'h5' => __( 'H5', 'themedraft-core' ),
					'h6' => __( 'H6', 'themedraft-core' ),
					'span' => __( 'Span', 'themedraft-core' ),
				],
				'condition' => [
					'slide_subtitle!' => '',
				],
			]
		);

		$repeater->add_control(
			'slide_title',
			[
				'label'       => esc_html__( 'Slide Title Text', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::WYSIWYG,
				'default'     => esc_html__( 'Saving #1 pet will not change the world, but for those 1 pet it will.', 'themedraft-core' ),
				'description' => esc_html__( 'Use H1 - H6 for title.', 'themedraft-core' ),
			]
		);

		$repeater->add_control(
			'slide_image',
			[
				'label'       => __( 'Slide Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'button_type',
			[
				'label'   => __( 'Button Type', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'icon-button',
				'options' => [
					'icon-button'   => __( 'Iconic Button', 'themedraft-core' ),
					'normal-button' => __( 'Normal Button', 'themedraft-core' ),
				],
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-business-phone-call',
					'library' => 'themedraft-custom-icons',
				],
				'condition'        => [
					'button_type' => 'icon-button'
				]
			]
		);

		$repeater->add_control(
			'button_subtitle',
			[
				'label'       => __( 'Button Subtitle', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Call Us On', 'themedraft-core' ),
				'placeholder' => __( 'Type button subtitle here', 'themedraft-core' ),
				'label_block' => true,
				'condition'   => [
					'button_type' => 'icon-button'
				]
			]
		);

		$repeater->add_control(
			'icon_button_text',
			[
				'label'       => esc_html__( 'Button Text', 'themedraft-core' ),
				'label_block' => true,
				'type'        => Controls_Manager::WYSIWYG,
				'default' => __( '<a href="tel:+880123456789" tabindex="0">+88 01234 56789</a>', 'themedraft-core' ),
				'description' => esc_html__( 'Type button text and click link icon from field top bar to add link.', 'themedraft-core' ),
				'condition'   => [
					'button_type' => 'icon-button'
				]
			]
		);

		$repeater->add_control(
			'normal_button_text',
			[
				'label'       => __( 'Button Text', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'separator'   => 'before',
				'default'     => __( 'Contact Us', 'themedraft-core' ),
				'placeholder' => __( 'Type button text here.', 'themedraft-core' ),
				'condition'   => [
					'button_type' => 'normal-button'
				]
			]
		);

		$repeater->add_control(
			'normal_button_url',
			[
				'label'         => __( 'Button URL', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
				'condition'     => [
					'button_type' => 'normal-button'
				]
			]
		);

		$repeater->add_control(
			'text_align',
			[
				'label'       => __( 'Text Align', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					'text-left'   => __( 'Left', 'themedraft-core' ),
					'text-center' => __( 'Center', 'themedraft-core' ),
					'text-right'  => __( 'Right', 'themedraft-core' ),
				],
				'default'     => 'text-left',
			]
		);

		$this->add_control(
			'slide_items',
			[
				'label'       => __( 'Slide List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'slide_subtitle' => __( 'Referring the world, and changed the defination of love.', 'themedraft-core' ),
						'slide_title'    => __( '<h2>Saving #1 pet will not change the world, but for those 1 pet it will.</h2>', 'themedraft-core' ),
					],
				],
				'title_field' => '{{{ slide_title }}}',
			]
		);

		$this->end_controls_section();

		//Start slider  options control
		$this->start_controls_section(
			'home_slider_options',
			[
				'label' => __( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_responsive_control(
			'slider_height',
			[
				'label'     => __( 'Slider Height (px)', 'themedraft-core' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'px' => [
						'min' => 300,
						'max' => 1200,
					],
				],
				'devices'   => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .td-home-slider-area .td-single-slide-item' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'slider_content_width',
			[
				'label'     => __( 'Content Wrapper Width (%)', 'themedraft-core' ),
				'type'      => Controls_Manager::SLIDER,
				'range'     => [
					'%' => [
						'min' => 40,
						'max' => 100,
					],
				],
				'devices'   => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .td-slider-content-wrapper .td-slider-content' => 'width: {{SIZE}}%;',
				],
			]
		);

		$this->add_responsive_control(
		    'content_wrapper_margin',
		    [
		        'label'      => esc_html__( 'Content Wrapper Margin', 'themedraft-core' ),
		        'type'       => Controls_Manager::DIMENSIONS,
		        'size_units' => [ 'px', '%', 'em' ],
		        'selectors'  => [
		            '{{WRAPPER}} .td-slider-content-wrapper .td-slider-content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
				'separator'   => 'before',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					'2000'  => __( '2 seconds', 'themedraft-core' ),
					'3000'  => __( '3 seconds', 'themedraft-core' ),
					'4000'  => __( '4 seconds', 'themedraft-core' ),
					'5000'  => __( '5 seconds', 'themedraft-core' ),
					'6000'  => __( '6 seconds', 'themedraft-core' ),
					'7000'  => __( '7 seconds', 'themedraft-core' ),
					'8000'  => __( '8 seconds', 'themedraft-core' ),
					'9000'  => __( '9 seconds', 'themedraft-core' ),
					'10000' => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => '4000',
				'condition'   => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'nav_arrow',
			[
				'label'       => __( 'Navigation Arrow On Hover', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'nav_dots',
			[
				'label'       => __( 'Navigation Dots', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'slider_animation',
			[
				'label'       => __( 'Animation', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'slider_shape',
			[
				'label'       => __( 'Bottom Wave shape', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'slider_overlay',
			[
				'label'       => __( 'Slider Overlay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->end_controls_section();
		//Slider  options control end

		$this->start_controls_section(
			'subtitle_style_options',
			[
				'label' => esc_html__( 'Subtitle', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'subtitle_typo',
				'label'    => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-slide-subtitle',
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-slide-subtitle' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'subtitle_bg_color',
			[
				'label'     => esc_html__( 'Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-slide-subtitle' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();


		// Title Style
		$this->start_controls_section(
			'title_style_options',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typo',
				'label'    => __( 'Typography', 'themedraft-core' ),
				'selector' => '
                    {{WRAPPER}} .td-slider-title h1,
                    {{WRAPPER}} .td-slider-title h2,
                    {{WRAPPER}} .td-slider-title h3,
                    {{WRAPPER}} .td-slider-title h4,
                    {{WRAPPER}} .td-slider-title h5,
                    {{WRAPPER}} .td-slider-title h6,
                    {{WRAPPER}} .td-slider-title p
                ',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-slider-title h1,{{WRAPPER}} .td-slider-title h2,{{WRAPPER}} .td-slider-title h3,
                    {{WRAPPER}} .td-slider-title h4,{{WRAPPER}} .td-slider-title h5,{{WRAPPER}} .td-slider-title h6,
                    {{WRAPPER}} .td-slider-title strong,{{WRAPPER}} .td-slider-title p' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();


		// Start Button section
		$this->start_controls_section(
			'icon_button_style_options',
			[
				'label' => esc_html__( 'Icon Button Style', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'td_icon_button_style_tabs' );

		//Default style tab start
		$this->start_controls_tab(
			'td_icon_btn_style_default',
			[
				'label' => esc_html__( 'Normal', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'icon_default_bg',
			[
				'label'     => esc_html__( 'Icon Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .button-icon,
					{{WRAPPER}} .slider-button-wrapper .button-icon:before' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_icon_color',
			[
				'label'     => esc_html__( 'Icon Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .button-icon' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_default_subtitle_color',
			[
				'label'     => esc_html__( 'Subtitle Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .button-subtitle' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_button_default_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [

					'{{WRAPPER}} .iconic-button-wrapper .button-text,
					{{WRAPPER}} .iconic-button-wrapper .button-text a' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'td_icon_btn_style_hover',
			[
				'label' => esc_html__( 'Hover', 'themedraft-core' ),
			]
		);


		$this->add_control(
			'icon_button_hover_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .iconic-button-wrapper .button-text a:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();// End Button section


		// Start Button section
		$this->start_controls_section(
			'button_style_options',
			[
				'label' => esc_html__( 'Normal Button Style', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->start_controls_tabs( 'td_button_style_tabs' );

		//Default style tab start
		$this->start_controls_tab(
			'td_btn_style_default',
			[
				'label' => esc_html__( 'Normal', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'button_default_bg',
			[
				'label'     => esc_html__( 'Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .td_button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_default_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .td_button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_default_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .td_button' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'td_btn_style_hover',
			[
				'label' => esc_html__( 'Hover', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'button_hover_bg',
			[
				'label'     => esc_html__( 'Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .td_button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_text_color',
			[
				'label'     => esc_html__( 'Text Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .td_button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => esc_html__( 'Border Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .slider-button-wrapper .td_button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();// End Button section


		$this->start_controls_section(
			'slider_dot_style',
			[
				'label' => esc_html__( 'Slider Dot And Arrow', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'dot_color',
			[
				'label'     => esc_html__( 'Dot Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-home-slider-area .slick-dots li:before' => 'color: {{VALUE}};',
				],
			]
		);


		$this->add_control(
			'active_dot_color',
			[
				'label'     => esc_html__( 'Active Dot Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-home-slider-area .slick-dots li:hover:before,
					{{WRAPPER}} .td-home-slider-area .slick-dots li.slick-active:before' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'arrow_bg',
			[
				'label'     => esc_html__( 'Arrow Background Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-home-slider-area .slick-arrow' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'arrow_hover_bg',
			[
				'label'     => esc_html__( 'Arrow Background Hover Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-home-slider-area .slick-arrow:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render In HTML
	protected function render() {
		$settings = $this->get_settings_for_display();
		$sliderId = rand(10, 1000);

		if(is_rtl()){
			$slide_dir = 'dir="rtl"';
			$slide_rtl = 'rtl: true,';
		}else{
			$slide_dir = '';
			$slide_rtl = '';
		}

		?>
		<div class="td-home-slider-area">
			<div <?php echo $slide_dir;?>  id="td-home-slider-<?php echo esc_attr($sliderId);?>" class="td-home-slider-wrapper">
				<?php
				if($settings['slide_items']){
					foreach($settings['slide_items'] as $slider){ ?>

						<div class="td-single-slide-item td-cover-bg" style="background-image: url(<?php echo esc_url($slider['slide_image']['url'])?>)">
							<?php if($settings['slider_overlay'] == true) : ?>
                                <div class="slider-overlay"></div>
							<?php endif; ?>
							<div class="td-tbl">
								<div class="td-tcell">
									<div class="container">
										<div class="row">
											<div class="col-lg-12 <?php echo esc_attr($slider['text_align']) ?>">
												<div class="td-slider-content-wrapper">
													<div class="td-slider-content">
														<?php if($slider['slide_subtitle']) : ?>
                                                        <<?php echo $slider['subtitle_tag'];?> class="td-slide-subtitle" data-animation="fadeInUp" data-delay=".5s">
                                                        <?php echo $slider['slide_subtitle'] ?>
                                                        </<?php echo $slider['subtitle_tag'];?>>
													    <?php endif; ?>

														<div class="td-slider-title" data-animation="fadeInUp"  data-delay="1s">
															<?php echo wpautop($slider['slide_title']); ?>
														</div>

														<div class="slider-button-wrapper">

                                                            <?php
                                                                if($slider['button_type'] == 'icon-button'){ ?>

                                                                    <div class="iconic-button-wrapper" data-animation="fadeInUp"  data-delay="1.5s">
                                                                        <span class="button-subtitle"><?php echo $slider['button_subtitle'];?></span>

                                                                        <div class="button-icon">
	                                                                        <?php
	                                                                        ThemeDraft_Custom_Icon_Render( $slider, 'icon-button', 'selected_icon' );
	                                                                        ?>
                                                                        </div>

                                                                        <div class="button-text">
                                                                            <?php echo $slider['icon_button_text']?>
                                                                        </div>

                                                                    </div>

                                                            <?php    }else{
                                                                    if(!empty($slider['normal_button_text'])){
	                                                                    $target = $slider['normal_button_url']['is_external'] ? ' target="_blank"' : '';
	                                                                    $nofollow = $slider['normal_button_url']['nofollow'] ? ' rel="nofollow"' : ''; ?>
                                                                        <a data-animation="fadeInUp"  data-delay="1.5s" href="<?php echo esc_url($slider['normal_button_url']['url'])?>" class="td_button" <?php echo  $target . $nofollow?>><?php echo esc_html($slider['normal_button_text']) ?></a>
                                                            <?php
                                                                    }
                                                                }
                                                            ?>
														</div>
													</div>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
						<?php

					}
				}
				?>
			</div>
            
            <?php if($settings['slider_shape'] == true) : ?>
            <div class="banner-shape"></div>
            <?php endif; ?>
		</div>


		<?php if($settings['slide_items'] && count($settings['slide_items']) > 1 ) :?>

			<script>
                (function ($) {
                    "use strict";
                    //Documnet Ready Function
                    $( document ).ready(function() {
                        // slider - active
                        function homeSlider() {
                            var SliderActive = $('#td-home-slider-<?php echo esc_js($sliderId)?>');

                            SliderActive.slick({
                                slidesToShow: 1,
                                autoplay: <?php echo json_encode($settings['autoplay'] == 'yes' ? true : false); ?>,
                                autoplaySpeed: <?php echo json_encode($settings['autoplay_interval'])?>,
                                speed: 1000, // slide speed
                                dots: <?php echo json_encode($settings['nav_dots'] == 'yes' ? true : false); ?>,
                                fade: true,
                                draggable: true,
                                pauseOnHover: false,
	                            <?php echo $slide_rtl;?>
                                arrows: <?php echo json_encode($settings['nav_arrow'] == 'yes' ? true : false); ?>,
                                prevArrow: '<i class="slick-arrow slick-prev fa fa-angle-left"></i>',
                                nextArrow: '<i class="slick-arrow slick-next fa fa-angle-right"></i>',
                                responsive: [
                                    {
                                        breakpoint: 992,
                                        settings: {
                                            //768-991
                                            arrows:false
                                        }
                                    },
                                    {
                                        breakpoint: 768,
                                        settings: {
                                            // 0 -767
                                            dots:true,
                                            arrows:false
                                        }
                                    }
                                ]
                            });

							<?php if($settings['slider_animation'] === 'yes') :?>
                            function doAnimations(elements) {
                                var animationEndEvents = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';
                                elements.each(function () {
                                    var $this = $(this);
                                    var $animationDelay = $this.data('delay');
                                    var $animationType = 'animated ' + $this.data('animation');
                                    $this.css({
                                        'animation-delay': $animationDelay,
                                        '-webkit-animation-delay': $animationDelay
                                    });
                                    $this.addClass($animationType).one(animationEndEvents, function () {
                                        $this.removeClass($animationType);
                                    });
                                });
                            }

                            SliderActive.on('init', function (e, slick) {
                                var $firstAnimatingElements = $('.td-single-slide-item:first-child').find('[data-animation]');
                                doAnimations($firstAnimatingElements);
                            });

                            SliderActive.on('beforeChange', function (e, slick, currentSlide, nextSlide) {
                                var $animatingElements = $('.td-single-slide-item[data-slick-index="' + nextSlide + '"]').find('[data-animation]');
                                doAnimations($animatingElements);
                            });
							<?php endif;?>
                        }
                        homeSlider();

                    });
                })(jQuery);
			</script>

		<?php endif; ?>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Home_Slider_Widget );
