<?php
namespace Elementor;

class ThemeDraft_Icon_box_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_icon_box';
	}

	public function get_title() {
		return esc_html__( 'Icon Box', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-server';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'td_icon_box_settings',
			[
				'label' => esc_html__( 'Icon Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'type',
		    [
		        'label'       => __( 'Icon Type', 'themedraft-core' ),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options'     => [
		            'icon'  => [
		                'title' => __( 'Icon', 'themedraft-core' ),
		                'icon'  => 'fa fa-smile-o',
		            ],
		            'image' => [
		                'title' => __( 'Image', 'themedraft-core' ),
		                'icon'  => 'fa fa-image',
		            ],
		        ],
		        'default'     => 'icon',
		        'toggle'      => false,
		    ]
		);

		$this->add_control(
		    'selected_icon',
		    [
		        'type'             => Controls_Manager::ICONS,
		        'fa4compatibility' => 'icon',
		        'label_block'      => true,
		        'default'          => [
		            'value'   => 'flaticon-pet-dog-1',
		            'library' => 'themedraft-pets-icon',
		        ],
		        'condition'        => [
		            'type' => 'icon'
		        ]
		    ]
		);

		$this->add_control(
		    'image',
		    [
		        'label'     => __( 'Image', 'themedraft-core' ),
		        'type'      => Controls_Manager::MEDIA,
		        'default'   => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		        'condition' => [
		            'type' => 'image'
		        ],
		        'dynamic'   => [
		            'active' => true,
		        ]
		    ]
		);

		$this->add_control(
		    'title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => __( 'Stylish Dog', 'themedraft-core' ),
		    ]
		);


		$this->add_control(
		    'desc',
		    [
		        'label'       => __( 'Description', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => __( 'There are many variations of passages of Lorem Ipsum available.', 'themedraft-core' ),
		        'label_block' => true,
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'icon_box_style',
		    [
		        'label' => esc_html__( 'Icon', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
		    'icon_size',
		    [
		        'label' => __( 'Icon Size', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 0,
		                'max' => 100,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],

		        'selectors' => [
		            '{{WRAPPER}} .td-icon-wrap' => 'font-size: {{SIZE}}{{UNIT}};',
		            '{{WRAPPER}} span.td-icon-wrap svg' => 'width: {{SIZE}}{{UNIT}};',
		            '{{WRAPPER}} .td-icon-wrap img.icon-box-image-icon' => 'max-width: {{SIZE}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_control(
		    'icon_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-icon-wrap' => 'color: {{VALUE}};',
		            '{{WRAPPER}} span.td-icon-wrap svg' => 'fill: {{VALUE}};',
		        ],

			    'condition' => [
			        'type' => 'icon',
			    ],
		    ]
		);

		$this->add_control(
			'icon_bg_color',
			[
				'label'       => esc_html__('Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-wrap' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'Title',
		    [
		        'label' => esc_html__( 'Title', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typography',
		        'label' => __( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-icon-box-title',
		    ]
		);

		$this->add_control(
			'title_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-box-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'title_spacing',
			[
				'label' => __( 'Spacing', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-icon-box-title' => 'padding-left: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'description',
			[
				'label' => esc_html__( 'Description', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'desc_typography',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-icon-box-content',
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-icon-box-content' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'desc_spacing',
			[
				'label' => __( 'Spacing', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-icon-box-content' => 'margin-top: {{SIZE}}{{UNIT}};',
				],
			]
		);



		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

		<div class="td-icon-box-wrapper">
			<div class="td-icon-and-title-wrap">

                    <span class="td-icon-wrap">
                        <?php if ( $settings['type'] === 'image' ) :
	                        if ( $settings['image']['url'] || $settings['image']['id'] ) :
		                        ?>

                                <img class="icon-box-image-icon" src="<?php echo $settings['image']['url']; ?>"
                                     alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">
	                        <?php endif;
                        elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon'] ) ) : ?>
	                        <?php ThemeDraft_Custom_Icon_Render( $settings, 'icon', 'selected_icon' ); ?>
                        <?php endif; ?>
                    </span>

                    <span class="td-icon-box-title"><?php echo $settings['title'];?></span>

			</div>

			<div class="td-icon-box-content">
				<?php echo $settings['desc'];?>
			</div>
		</div>

		<?php

	}

}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Icon_box_Widget );