<?php
namespace Elementor;

class ThemeDraft_Pricing_List_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_pricing_list';
	}

	public function get_title() {
		return esc_html__( 'Pricing List', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-rich';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'pricing_basic_settings',
			[
				'label' => esc_html__( 'Pricing Basic List', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'basic_button_text',
			[
				'label'       => __( 'Button Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Basic Plan',
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
		    'basic_title',
		    [
		        'label'       => __('Title', 'themedraft-core'),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'Pet Grooming',
		        'label_block' => true,
		    ]
		);

		$repeater->add_control(
		    'type',
		    [
		        'label'       => __( 'Icon Type', 'themedraft-core' ),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options'     => [
		            'icon'  => [
		                'title' => __( 'Icon', 'themedraft-core' ),
		                'icon'  => 'fa fa-smile-o',
		            ],
		            'image' => [
		                'title' => __( 'Image', 'themedraft-core' ),
		                'icon'  => 'fa fa-image',
		            ],
		        ],
		        'default'     => 'icon',
		        'toggle'      => false,
		    ]
		);

		$repeater->add_control(
		    'selected_icon',
		    [
		        'label'       => __( 'Select Icon', 'themedraft-core' ),
		        'type'             => Controls_Manager::ICONS,
		        'fa4compatibility' => 'icon',
		        'label_block'      => true,
		        'default'          => [
		            'value'   => 'flaticon-business-wallet-1',
		            'library' => 'themedraft-flaticon',
		        ],
		        'condition'        => [
		            'type' => 'icon'
		        ]
		    ]
		);

		$repeater->add_control(
		    'image',
		    [
		        'label'     => __( 'Image', 'themedraft-core' ),
		        'type'      => Controls_Manager::MEDIA,
		        'default'   => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		        'condition' => [
		            'type' => 'image'
		        ],
		        'dynamic'   => [
		            'active' => true,
		        ]
		    ]
		);

		$repeater->add_control(
		    'basic_price',
		    [
		        'label'       => __( 'Price', 'themedraft-core' ),
		        'label_block'       => true,
		        'type'        => Controls_Manager::TEXT,
		        'default'     => '$100',
		    ]
		);

		$repeater->add_control(
		    'basic_desc',
		    [
		        'label'       => __( 'Description', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => 'If your dog has separation anxiety we encourage you to bring something that smells like home.',
		    ]
		);

		$repeater->add_control(
		    'basic_item_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		    ]
		);

		$this->add_control(
		    'pricing_basic_lists',
		    [
		        'label'       => __('Pricing List', 'themedraft-core'),
		        'type'        => Controls_Manager::REPEATER,
		        'fields'      => $repeater->get_controls(),
		        'default'     => [
		            [
		                'title'        => 'Pet Grooming',
		                'basic_price'        => '$100',
		                'basic_desc'        => 'If your dog has separation anxiety we encourage you to bring something that smells like home.',
		            ],
		        ],
		        'title_field' => '{{{ basic_title }}}',
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'pricing_extra_settings',
			[
				'label' => esc_html__( 'Pricing Extra List', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'extra_button_text',
			[
				'label'       => __( 'Button Text', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Extra Plan',
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'extra_title',
			[
				'label'       => __('Title', 'themedraft-core'),
				'type'        => Controls_Manager::TEXT,
				'default'     => 'Pet Grooming',
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'type2',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon2'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image2' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon2',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon2',
			[
				'label'       => __( 'Select Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-business-wallet-1',
					'library' => 'themedraft-flaticon',
				],
				'condition'        => [
					'type2' => 'icon2'
				]
			]
		);

		$repeater->add_control(
			'image2',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type2' => 'image2'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'extra_price',
			[
				'label'       => __( 'Price', 'themedraft-core' ),
				'label_block'       => true,
				'type'        => Controls_Manager::TEXT,
				'default'     => '$10',
			]
		);

		$repeater->add_control(
			'extra_desc',
			[
				'label'       => __( 'Description', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => 'If your dog has separation anxiety we encourage you to bring something that smells like home.',
			]
		);

		$repeater->add_control(
			'extra_item_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
			]
		);

		$this->add_control(
			'pricing_extra_lists',
			[
				'label'       => __('Pricing List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => 'Pet Grooming',
						'extra_price'        => '$10',
						'extra_desc'        => 'If your dog has separation anxiety we encourage you to bring something that smells like home.',
					],
				],
				'title_field' => '{{{ extra_title }}}',
			]
		);

		$this->end_controls_section();


	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

		<div class="td-pricing-list-wrapper">
			<div class="td-pricing-list-button-wrapper">
                <div class="td-pricing-list-button basic">
                    <span class="basic-plan"><?php echo $settings['basic_button_text'];?></span>
                    <span class="extra-plan"><?php echo $settings['extra_button_text'];?></span>
                </div>
			</div>

			<div class="td-pricing-list-container">
				<div class="td-basic-list-container active">
					<?php if($settings['pricing_basic_lists']){
						foreach ($settings['pricing_basic_lists'] as $basic_item){ ?>

							<div class="td-basic-items">
								<div class="icon-title-price-wrapper">
									<div class="pricing-icon-wrapper" style="background-color: <?php echo $basic_item['basic_item_color']?>">
										<?php if ( $basic_item['type'] === 'image' ) :
											if ( $basic_item['image']['url'] || $basic_item['image']['id'] ) :
												?>
												<div class="td-icon-wrapper td-image-icon">
													<img src="<?php echo $basic_item['image']['url']; ?>"
													     alt="<?php echo get_post_meta( $basic_item['image']['id'], '_wp_attachment_image_alt', true ); ?>">
												</div>
											<?php endif;
										elseif ( ! empty( $basic_item['icon'] ) || ! empty( $basic_item['selected_icon'] ) ) : ?>
											<div class="td-icon-wrapper td-font-icon">
												<?php themedraft_custom_icon_render( $basic_item, 'icon', 'selected_icon' ); ?>
											</div>
										<?php endif; ?>
									</div>

									<h6 class="title"><?php echo $basic_item['basic_title'];?></h6>
									<span class="price" style="color: <?php echo $basic_item['basic_item_color'];?>"><?php echo $basic_item['basic_price'];?></span>
								</div>
                                <div class="desc"><?php echo $basic_item['basic_desc'];?></div>
							</div>
					<?php }
					} ?>

				</div>



				<div class="td-extra-list-container">
					<?php if($settings['pricing_extra_lists']){
						foreach ($settings['pricing_extra_lists'] as $extra_item){ ?>

							<div class="td-extra-items">
								<div class="icon-title-price-wrapper">
									<div class="pricing-icon-wrapper" style="background-color: <?php echo $extra_item['extra_item_color']?>">
										<?php if ( $extra_item['type2'] === 'image2' ) :
											if ( $extra_item['image2']['url'] || $extra_item['image2']['id'] ) :
												?>
												<div class="td-icon-wrapper td-image-icon">
													<img src="<?php echo $extra_item['image2']['url']; ?>"
													     alt="<?php echo get_post_meta( $extra_item['image2']['id'], '_wp_attachment_image_alt', true ); ?>">
												</div>
											<?php endif;
										elseif ( ! empty( $extra_item['icon2'] ) || ! empty( $extra_item['selected_icon2'] ) ) : ?>
											<div class="td-icon-wrapper td-font-icon">
												<?php themedraft_custom_icon_render( $extra_item, 'icon2', 'selected_icon2' ); ?>
											</div>
										<?php endif; ?>
									</div>

									<h6 class="title"><?php echo $extra_item['extra_title'];?></h6>
									<span class="price" style="color: <?php echo $extra_item['extra_item_color']?>"><?php echo $extra_item['extra_price'];?></span>
								</div>

                                <div class="desc"><?php echo $extra_item['extra_desc'];?></div>
							</div>
						<?php }
					} ?>
				</div>
			</div>

            <script>
                jQuery(document).ready(function ($) {
                    $(".basic-plan").on("click", function () {
                        $(".td-pricing-list-button").addClass("basic");
                        $(".td-pricing-list-button").removeClass("extra");

                        $(".td-extra-list-container").removeClass("active");
                        $(".td-basic-list-container").addClass("active");

                    });

                    $(".extra-plan").on("click", function () {
                        $(".td-pricing-list-button").removeClass("basic");
                        $(".td-pricing-list-button").addClass("extra");
                        $(".td-basic-list-container").removeClass("active");
                        $(".td-extra-list-container").addClass("active");
                    });

                });
            </script>

		</div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Pricing_List_Widget );