<?php

namespace Elementor;

class ThemeDraft_Pricing_Table_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_pricing_table';
	}

	public function get_title() {
		return esc_html__( 'Pricing Table', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-rich';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'pricing_table_options',
			[
				'label' => esc_html__( 'Top Content', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image',
			[
				'label'       => __( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Regular Checkup', 'themedraft-core' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'price',
			[
				'label'   => __( 'Price', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( '$99', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'time_period',
			[
				'label'   => __( 'Time Period', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Per Session', 'themedraft-core' ),
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'features_list_settings',
			[
				'label' => esc_html__( 'Features List', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'text',
			[
				'label'       => __( 'Text', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'List Item Text', 'themedraft-core' ),
				'label_block' => true,
			]
		);


		$repeater->add_control(
			'selected_icon',
			[
				'label'            => __( 'Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'far fa-dot-circle',
					'library' => 'regular',
				],
			]
		);

		$repeater->add_control(
			'icon_color',
			[
				'label'   => esc_html__( 'Icon Color', 'themedraft-core' ),
				'type'    => Controls_Manager::COLOR,
				'default' => '#49b3e6',
			]
		);

		$repeater->add_control(
			'item_link',
			[
				'label'         => __( 'Link', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->add_control(
			'list_items',
			[
				'label'       => __( 'List', 'themedraft-core' ),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'text' => __( 'List Item Text', 'themedraft-core' ),
					],
				],
				'title_field' => '{{{ text }}}',
			]
		);
		$this->end_controls_section();

		$this->start_controls_section(
			'pricing_button',
			[
				'label' => esc_html__( 'Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'btn_text',
			[
				'label'   => __( 'Button Text', 'themedraft-core' ),
				'type'    => Controls_Manager::TEXT,
				'default' => __( 'Order Now', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'button_link',
			[
				'label'         => __( 'Button Link', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '#',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'background_icon',
		    [
		        'label' => esc_html__( 'Background Icon', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_CONTENT,
		    ]
		);

		$this->add_control(
			'bg_icon',
			[
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-pet-dog-2',
					'library' => 'themedraft-pets-icon',
				],
			]
		);

		$this->add_control(
			'bg_icon_color',
			[
				'label'       => esc_html__('Background Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .pricing-bg-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .pricing-bg-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'bg_icon_size',
			[
				'label' => __( 'Icon Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 500,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .pricing-bg-icon' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .pricing-bg-icon svg' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'price_and_duration_style',
			[
				'label' => esc_html__( 'Price & Duration', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'price_duration_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-pricing-price,{{WRAPPER}} .td-pricing-time' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

		// Button Style
		$this->start_controls_section(
			'pricing_button_style',
			[
				'label' => esc_html__( 'Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);


		$this->start_controls_tabs('td_button_style_tabs');

		//Default style start
		$this->start_controls_tab(
			'btn_normal_style',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_normal_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_pricing_button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_normal_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_pricing_button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_normal_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_pricing_button' => 'border-color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'btn_hover_style',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_hover_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_pricing_button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_pricing_button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td_button.td_pricing_button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();


	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

        <div class="td-pricing-table-wrapper">
            <div class="td-pricing-image td-cover-bg" style="background-image: url(<?php echo esc_url( $settings['image']['url'] ) ?>)"></div>

            <div class="td-pricing-table-content">
                <div class="pricing-bg-icon">
	                <?php ThemeDraft_Custom_Icon_Render( $settings, 'icon', 'bg_icon' ); ?>
                </div>
                <div class="td-pricing-title-and-price-wrapper">
                    <h4 class="td-pricing-title"><?php echo $settings['title']; ?></h4>
                    <h5 class="td-pricing-price"><?php echo $settings['price']; ?></h5>
                    <span class="td-pricing-time"> / <?php echo $settings['time_period']; ?></span>
                </div>

                <div class="td-pricing-features">
                    <div class="td-icon-list-wrapper">
                        <ul class="td-list-default-layout">
							<?php
							if ( $settings['list_items'] ) {
								foreach ( $settings['list_items'] as $list_item ) { ?>
                                    <li class="td-icon-list-item">
                                    <span class="td-icon-list-icon"
                                          style="color: <?php echo $list_item['icon_color']; ?>">
                                        <?php ThemeDraft_Custom_Icon_Render( $list_item, 'icon', 'selected_icon' ); ?>
                                    </span>
                                        <span class="td-icon-list-text">
                                    <?php if ( ! empty( $list_item['item_link']['url'] ) ) :
                                    $target = $list_item['item_link']['is_external'] ? ' target="_blank"' : '';
                                    $nofollow = $list_item['item_link']['nofollow'] ? ' rel="nofollow"' : '';
                                    ?>
                                    <a href="<?php echo $list_item['item_link']['url']; ?>" <?php echo $target . $nofollow; ?>>
                                    <?php endif;
                                    ?>
                                    <?php echo $list_item['text']; ?>
                                    <?php if ( ! empty( $list_item['item_link']['url'] ) ) : ?>
                                    </a>
                                    <?php endif;
                                    ?>
                                    </span>
                                    </li>
									<?php
								}
							}
							?>
                        </ul>
                    </div>
                </div>

				<?php if ( ! empty( $settings['btn_text'] ) ) :
					$btn_target = $settings['button_link']['is_external'] ? ' target="_blank"' : '';
					$btn_nofollow = $settings['button_link']['nofollow'] ? ' rel="nofollow"' : '';
					?>

                    <div class="td-pricing-button">
                        <a href="<?php echo $settings['button_link']['url']; ?>  <?php echo $btn_target . $btn_nofollow; ?>"
                           class="td_button td_pricing_button"><?php echo $settings['btn_text']; ?></a>
                    </div>
				<?php endif; ?>
            </div>
        </div>

		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Pricing_Table_Widget );