<?php
namespace Elementor;

class ThemeDraft_Promo_Box_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_promo_box';
	}

	public function get_title() {
		return esc_html__( 'Promo Box', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-box-3';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'promo_box_settings',
			[
				'label' => esc_html__( 'Promo Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'box_number',
		    [
		        'label'       => __( 'Box Number', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => __( '01', 'themedraft-core' ),
		    ]
		);

		$this->add_control(
		    'type',
		    [
		        'label'       => __( 'Icon Type', 'themedraft-core' ),
		        'type'        => Controls_Manager::CHOOSE,
		        'label_block' => false,
		        'options'     => [
		            'icon'  => [
		                'title' => __( 'Icon', 'themedraft-core' ),
		                'icon'  => 'fa fa-smile-o',
		            ],
		            'image' => [
		                'title' => __( 'Image', 'themedraft-core' ),
		                'icon'  => 'fa fa-image',
		            ],
		        ],
		        'default'     => 'icon',
		        'toggle'      => false,
		    ]
		);

		$this->add_control(
		    'selected_icon',
		    [
		        'type'             => Controls_Manager::ICONS,
		        'fa4compatibility' => 'icon',
		        'label_block'      => true,
		        'default'          => [
		            'value'   => 'flaticon-pet-animal-kingdom-1',
		            'library' => 'themedraft-pets-icon',
		        ],
		        'condition'        => [
		            'type' => 'icon'
		        ]
		    ]
		);

		$this->add_control(
		    'image',
		    [
		        'label'     => __( 'Image', 'themedraft-core' ),
		        'type'      => Controls_Manager::MEDIA,
		        'default'   => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		        'condition' => [
		            'type' => 'image'
		        ],
		        'dynamic'   => [
		            'active' => true,
		        ]
		    ]
		);

		$this->add_control(
		    'title',
		    [
		        'label'       => __( 'Box Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => __( 'Awarded service', 'themedraft-core' ),
		        'placeholder' => __( 'Type box title here.', 'themedraft-core' ),
		    ]
		);


		$this->add_control(
		    'link',
		    [
		        'label'         => __( 'Title Link ( Optional )', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		    ]
		);

		$this->add_control(
		    'desc',
		    [
		        'label'       => __( 'Box Description', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => __( 'There are variations passages of Lorem Ipsum available.', 'themedraft-core' ),
		        'label_block' => true,
		    ]
		);


		$this->end_controls_section();

		$this->start_controls_section(
		    'promo_number_style',
		    [
		        'label' => esc_html__( 'Number', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		        'condition' => [
			        'box_number!' => '',
		        ]
		    ]
		);

		$this->add_control(
		    'number_color',
		    [
		        'label'       => esc_html__('Number Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .box-number' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'number_bg_color',
			[
				'label'       => esc_html__('Number Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .box-number' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'promo_icon_style',
			[
				'label' => esc_html__( 'Icon', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
		    'icon_size',
		    [
		        'label' => __( 'Icon Size', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 0,
		                'max' => 150,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],

		        'selectors' => [
		            '{{WRAPPER}} .box-icon' => 'font-size: {{SIZE}}{{UNIT}};',
		            '{{WRAPPER}} .box-icon .promo-image-icon' => 'max-width: {{SIZE}}{{UNIT}};',
		            '{{WRAPPER}} .box-icon svg' => 'max-width: {{SIZE}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
			'icon_bg_size',
			[
				'label' => __( 'Icon Background Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 250,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .box-icon' => 'height: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};line-height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'icon_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .box-icon' => 'color: {{VALUE}};',
					'{{WRAPPER}} .box-icon svg' => 'fill: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'icon_bg_color',
			[
				'label'       => esc_html__('Icon Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .box-icon' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'promo_text_style',
			[
				'label' => esc_html__( 'Text', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'       => esc_html__('Title Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .promo-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Title Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .promo-title:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'desc_color',
			[
				'label'       => esc_html__('Description Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .promo-box-content' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$target   = $settings['link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';
		?>

		<div class="single-promo-box">
			<div class="box-icon">

                <?php if ( $settings['box_number'] ) : ?>
                <div class="box-number"><?php echo $settings['box_number'] ?></div>
                <?php endif; ?>

				<?php if ( $settings['type'] === 'image' ) :
					if ( $settings['image']['url'] || $settings['image']['id'] ) :
						?>

						<img class="promo-image-icon" src="<?php echo $settings['image']['url']; ?>"
						     alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">
					<?php endif;
				elseif ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon'] ) ) : ?>
					<?php ThemeDraft_Custom_Icon_Render( $settings, 'icon', 'selected_icon' ); ?>
				<?php endif; ?>
			</div>

            <div class="promo-box-content">
	            <?php if(!empty($settings['link']['url'])) : ?>
		            <a href="<?php echo $settings['link']['url'];?>" class="promo-title" <?php echo $target . $nofollow ;?>><?php echo $settings['title'];?></a>
	            <?php else : ?>
		            <h4 class="promo-title"><?php echo $settings['title'];?></h4>
	            <?php endif; ?>
                <?php echo $settings['desc'];?>
            </div>
		</div>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Promo_Box_Widget );