<?php
namespace Elementor;

class ThemeDraft_Search_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_search';
	}

	public function get_title() {
		return esc_html__( 'Search', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-site-search';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		$this->start_controls_section(
			'search_settings',
			[
				'label' => esc_html__( 'Search', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'search_placeholder',
		    [
		        'label'       => __( 'Placeholder', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => 'Search...'
		    ]
		);
		$this->end_controls_section();


		$this->start_controls_section(
		    'search_inout_style',
		    [
		        'label' => esc_html__( 'Input', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'search_typo',
		        'label' => esc_html__( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-search-widget.search-form input',
		    ]
		);

		$this->add_control(
			'input_bg_color',
			[
				'label'       => esc_html__('Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-search-widget.search-form input' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'placeholder_color',
		    [
		        'label'       => esc_html__('Placeholder Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
			        '{{WRAPPER}} .td-search-widget ::placeholder' => 'color: {{VALUE}};',
			        '{{WRAPPER}} .td-search-widget :-ms-input-placeholder' => 'color: {{VALUE}};',
			        '{{WRAPPER}} .td-search-widget ::-ms-input-placeholder' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
		    'text_color',
		    [
		        'label'       => esc_html__('Text Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-search-widget input' => 'color: {{VALUE}};',
		        ],
                'separator' => 'after',
		    ]
		);

		$this->add_responsive_control(
			'height',
			[
				'label' => esc_html__( 'Height ( px )', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 10,
						'max' => 150,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-search-widget input' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'width',
			[
				'label' => esc_html__( 'Width ( % )', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['%'],
				'range' => [
					'%' => [
						'min' => 10,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
                'separator' => 'after',
				'selectors' => [
					'{{WRAPPER}} .td-search-widget' => 'width: {{SIZE}}%;',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'search_border',
				'label' => __( 'Border', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-search-widget.search-form input',
			]
		);

		$this->add_responsive_control(
			'border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-search-widget.search-form input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'after',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'search_btn_style',
		    [
		        'label' => esc_html__( 'Button', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'btn_background_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-search-widget .search-submit' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'btn_background_color_on_hover',
			[
				'label'       => esc_html__('Background Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-search-widget .search-submit:hover' => 'background-color: {{VALUE}};border-color: {{VALUE}};',
				],
			]
		);


		$this->add_control(
		    'btn_icon_color',
		    [
		        'label'       => esc_html__('Icon Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-search-widget .search-submit' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'btn_icon_color_on_hover',
			[
				'label'       => esc_html__('Icon Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-search-widget .search-submit:hover' => 'color: {{VALUE}};',
				],
                'separator' => 'after',
			]
		);

		$this->add_responsive_control(
			'btn_border_radius',
			[
				'label'      => esc_html__( 'Border Radius', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-search-widget .search-submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
		    'btn_size',
		    [
		        'label' => esc_html__( 'Button Size', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['px'],
		        'range' => [
		            'px' => [
		                'min' => 0,
		                'max' => 100,
		            ],
		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],

		        'selectors' => [
		            '{{WRAPPER}} .td-search-widget .search-submit' => 'width: {{SIZE}}{{UNIT}};height: {{SIZE}}{{UNIT}};margin-top:calc(-{{SIZE}}{{UNIT}} / 2) !important;',
		        ],
		        'separator' => 'before',
		    ]
		);

		$this->add_responsive_control(
			'btn_icon_size',
			[
				'label' => esc_html__( 'Icon Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-search-widget .search-submit' => 'font-size:{{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'btn_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'allowed_dimensions' => ['right','left' ],
				'selectors'  => [
					'{{WRAPPER}} .td-search-widget .search-submit' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->end_controls_section();

	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$unique_id = uniqid('valkuta-search-form-');
		?>

		<form role="search" method="get" class="td-search-widget search-form" action="<?php echo esc_url( home_url( '/' ) ); ?>">
			<label for="<?php echo esc_attr($unique_id); ?>">
				<span class="screen-reader-text"><?php echo _x( 'Search for:', 'label', 'themedraft-core' ); ?></span>
				<input type="search" id="<?php echo esc_attr($unique_id); ?>" class="search-field" placeholder="<?php echo esc_attr__( $settings['search_placeholder']);?>" value="<?php echo get_search_query(); ?>" required name="s" />
			</label>
			<button type="submit" class="search-submit"><i class="fas fa-search"></i></button>
		</form>
		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Search_Widget );