<?php

namespace Elementor;

class ThemeDraft_Section_Title_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_section_title';
	}

	public function get_title() {
		return esc_html__( 'Section Title', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-t-letter';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'Section_title_settings',
			[
				'label' => esc_html__( 'Section Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'subtitle',
			[
				'label'       => esc_html__( 'Subtitle', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'label_block' => true,
				'row'         => 4,
				'default'     => esc_html__( 'Our Introduction', 'themedraft-core' ),
				'placeholder' => esc_html__( 'Type subtitle here', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'subtitle_tag',
			[
				'label'       => esc_html__( 'Subtitle Tag', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,

				'options' => [
					'h1' => esc_html__( 'H1', 'themedraft-core' ),
					'h2' => esc_html__( 'H2', 'themedraft-core' ),
					'h3' => esc_html__( 'H3', 'themedraft-core' ),
					'h4' => esc_html__( 'H4', 'themedraft-core' ),
					'h5' => esc_html__( 'H5', 'themedraft-core' ),
					'h6' => esc_html__( 'H6', 'themedraft-core' ),
				],

				'default'   => 'h6',
				'condition' => [
					'subtitle!' => '',
				],
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => esc_html__( 'We can keep them happy', 'themedraft-core' ),
				'placeholder' => esc_html__( 'Type section title here', 'themedraft-core' ),
			]
		);

		$this->add_control(
			'title_tag',
			[
				'label'       => esc_html__( 'Title Tag', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,

				'options' => [
					'h1' => esc_html__( 'H1', 'themedraft-core' ),
					'h2' => esc_html__( 'H2', 'themedraft-core' ),
					'h3' => esc_html__( 'H3', 'themedraft-core' ),
					'h4' => esc_html__( 'H4', 'themedraft-core' ),
					'h5' => esc_html__( 'H5', 'themedraft-core' ),
					'h6' => esc_html__( 'H6', 'themedraft-core' ),
				],

				'default' => 'h2',
			]
		);

		$this->add_control(
			'desc',
			[
				'label'       => esc_html__( 'Description', 'themedraft-core' ),
				'type'        => Controls_Manager::WYSIWYG,
				'default'     => esc_html__( 'Type description text here.', 'themedraft-core' ),
				'placeholder' => esc_html__( 'Type description text here.', 'themedraft-core' ),
			]
		);

		$this->add_responsive_control(
			'text_align',
			[
				'label'       => esc_html__( 'Text Align', 'themedraft-core' ),
				'description' => esc_html__( '', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,

				'options' => [
					'left' => [
						'title' => __( 'Left', 'themedraft-core' ),
						'icon'  => 'fa fa-align-left',
					],

					'center' => [
						'title' => __( 'Center', 'themedraft-core' ),
						'icon'  => 'fa fa-align-center',
					],

					'right' => [
						'title' => __( 'Right', 'themedraft-core' ),
						'icon'  => 'fa fa-align-right',
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-section-title-wrap' => 'text-align: {{VALUE}};',
				],

			]
		);

		$this->add_responsive_control(
			'wrapper_width',
			[
				'label'           => __( 'Title Container Width ( % )', 'themedraft-core' ),
				'type'            => Controls_Manager::SLIDER,
				'size_units'      => [ '%' ],
				'range'           => [
					'%' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices'         => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 100,
					'unit' => '%',
				],
				'tablet_default'  => [
					'size' => 100,
					'unit' => '%',
				],
				'mobile_default'  => [
					'size' => 100,
					'unit' => '%',
				],
				'selectors'       => [
					'{{WRAPPER}} .td-section-title-content' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'wrapper_margin',
			[
				'label'      => esc_html__( 'Wrapper Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-section-title-wrap' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'subtitle_style',
			[
				'label'     => esc_html__( 'Subtitle', 'themedraft-core' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'subtitle!' => '',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'subtitle_typography',
				'label'    => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-section-title-wrap .subtitle',
			]
		);

		$this->add_control(
			'subtitle_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-section-title-wrap .subtitle' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'subtitle_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-section-title-wrap .subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'title_style',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'title_typography',
				'label'    => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-section-title-wrap .title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-section-title-wrap .title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'title_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-section-title-wrap .title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'description_style',
			[
				'label'     => esc_html__( 'Description', 'themedraft-core' ),
				'tab'       => Controls_Manager::TAB_STYLE,
				'condition' => [
					'desc!' => '',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name'     => 'description_typography',
				'label'    => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-section-title-wrap .title-description',
			]
		);

		$this->add_control(
			'description_color',
			[
				'label'     => esc_html__( 'Color', 'themedraft-core' ),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-section-title-wrap .title-description' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_responsive_control(
			'description_margin',
			[
				'label'      => esc_html__( 'Margin', 'themedraft-core' ),
				'type'       => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors'  => [
					'{{WRAPPER}} .td-section-title-wrap .title-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'title_icon',
			[
				'label' => esc_html__( 'Icon & Line Image', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'enable_icon',
			[
				'label'     => esc_html__( 'Enable Icon', 'themedraft-core' ),
				'type'      => Controls_Manager::SWITCHER,
				'label_on'  => esc_html__( 'Yes', 'themedraft-core' ),
				'label_off' => esc_html__( 'No', 'themedraft-core' ),
				'default'   => 'no',
			]
		);

		$this->add_control(
			'selected_icon',
			[
				'label'     => esc_html__( 'Icon', 'themedraft-core' ),
				'type'             => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-pet-toyger-cat',
					'library' => 'themedraft-pet',
				],
				'condition' => [
					'enable_icon' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 100,
						'max' => 650,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-section-title-icon' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .td-section-title-icon svg' => 'width: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'enable_icon' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'top_position',
			[
				'label' => __( 'Position From Top', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => -1500,
						'max' => 1500,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-section-title-icon' => 'top: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'enable_icon' => 'yes',
				],
			]
		);

		$this->add_responsive_control(
			'left_position',
			[
				'label' => __( 'Position From Left', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => -1500,
						'max' => 1500,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-section-title-icon' => 'left: {{SIZE}}{{UNIT}};',
				],
				'condition' => [
					'enable_icon' => 'yes',
				],
			]
		);

		$this->add_control(
			'line_image',
			[
				'label'       => __( 'Line Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => THEMEDRAFT_CORE_ASSETS . 'images/shape-blue.png',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$number = rand(100, 10000);
		?>

        <div class="row">
            <div class="col-lg-12">
                <div class="td-section-title-wrap section-title-<?php echo $number ?>">
                    <div class="td-section-title-content">
						<?php if($settings['enable_icon'] == 'yes') : ?>

                            <div class="td-section-title-icon">
								<?php ThemeDraft_Custom_Icon_Render( $settings, 'icon', 'selected_icon' ); ?>
                            </div>
						<?php endif;?>

						<?php if ( $settings['subtitle'] ) : ?>
                        <<?php echo $settings['subtitle_tag']; ?> class="subtitle"><?php echo $settings['subtitle']; ?></<?php echo $settings['subtitle_tag']; ?>>
					<?php endif; ?>

                    <<?php echo $settings['title_tag']; ?> class="title"><?php echo $settings['title']; ?>
                </<?php echo $settings['title_tag']; ?>>
				<?php if ( $settings['desc'] ) : ?>
                    <div class="title-description">
						<?php echo $settings['desc']; ?>
                    </div>
				<?php endif; ?>
            </div>
        </div>
        </div>

        <style>
            .td-section-title-wrap.section-title-<?php echo $number ?> .subtitle:before{
                background-image: url("<?php echo $settings['line_image']['url'];?>");
            }
        </style>
        </div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Section_Title_Widget );