<?php
namespace Elementor;

class ThemeDraft_Service_Box_Two_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_service_box_two';
	}

	public function get_title() {
		return esc_html__( 'Service Box Two', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-suitcase';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'service_box_settings',
			[
				'label' => esc_html__( 'Service Boxes', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();


		$repeater->add_control(
			'type',
			[
				'label'       => __( 'Icon Type', 'themedraft-core' ),
				'type'        => Controls_Manager::CHOOSE,
				'label_block' => false,
				'options'     => [
					'icon'  => [
						'title' => __( 'Icon', 'themedraft-core' ),
						'icon'  => 'fa fa-smile-o',
					],
					'image' => [
						'title' => __( 'Image', 'themedraft-core' ),
						'icon'  => 'fa fa-image',
					],
				],
				'default'     => 'icon',
				'toggle'      => false,
			]
		);

		$repeater->add_control(
			'selected_icon',
			[
				'type'             => Controls_Manager::ICONS,
				'label'       => __( 'Icon', 'themedraft-core' ),
				'fa4compatibility' => 'icon',
				'label_block'      => true,
				'default'          => [
					'value'   => 'flaticon-pet-animal-kingdom-1',
					'library' => 'themedraft-pets-icon',
				],
				'condition'        => [
					'type' => 'icon'
				]
			]
		);

		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				'condition' => [
					'type' => 'image'
				],
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'icon_color',
			[
				'label'       => esc_html__('Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
			]
		);

		$repeater->add_control(
			'icon_bg_color',
			[
				'label'       => esc_html__('Icon Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Box Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => __( 'Awarded service', 'themedraft-core' ),
				'placeholder' => __( 'Type box title here.', 'themedraft-core' ),
			]
		);

		$repeater->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'themedraft-core' ),
				'type'        => Controls_Manager::WYSIWYG,
				'default'     => __( 'There are many variations of passages of Lorem available, but the majority have suffered alteration in some form.', 'themedraft-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'button_text',
			[
				'label'       => __( 'Button Text', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Read More', 'themedraft-core' ),
			]
		);

		$repeater->add_control(
			'button_link',
			[
				'label'         => __( 'Details Url', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);


		$this->add_control(
			'service_boxes',
			[
				'label'       => __('Service List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => __('Full diagnostics', 'themedraft-core'),
						'desc' => __('There are many variations of passages of Lorem available, but the majority have suffered alteration in some form.', 'themedraft-core'),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
			'desktop_column',
			[
				'label'   => __( 'Desktop Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-12' => __( '1 Column', 'themedraft-core' ),
					'col-lg-6'  => __( '2 Column', 'themedraft-core' ),
					'col-lg-4'  => __( '3 Column', 'themedraft-core' ),
					'col-lg-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'tab_column',
			[
				'label'   => __( 'Tablet Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-md-6',
				'options' => [
					'col-md-12' => __( '1 Column', 'themedraft-core' ),
					'col-md-6'  => __( '2 Column', 'themedraft-core' ),
					'col-md-4'  => __( '3 Column', 'themedraft-core' ),
					'col-md-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'service_icon_style',
			[
				'label' => esc_html__( 'Icon', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_responsive_control(
			'icon_size',
			[
				'label' => __( 'Icon Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-service-box-2-icon' => 'font-size: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .td-service-box-2-icon img.service-image-icon' => 'max-width: {{SIZE}}{{UNIT}};',
					'{{WRAPPER}} .td-service-box-2-icon svg' => 'max-width: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'service_title_style',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-service-box-2-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-box-2-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} a.td-service-box-2-title:hover' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'service_button_style',
			[
				'label' => esc_html__( 'Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'       => esc_html__('Text Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td_text_button.td-service-box-2-button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'text_hover_color',
			[
				'label'       => esc_html__('Text Color On Hover', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td_text_button.td-service-box-2-button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

        <div class="td-service-box-2-wrapper">
            <div class="row">
				<?php if($settings['service_boxes']){
					$box_number = 0;
					foreach ($settings['service_boxes'] as $service_box){
						$box_number++;
						$target   = $service_box['button_link']['is_external'] ? ' target="_blank"' : '';
						$nofollow = $service_box['button_link']['nofollow'] ? ' rel="nofollow"' : '';
						?>

                        <div class="service-box-column <?php echo $settings['desktop_column'] . ' ' . $settings['tab_column'];?>">
                            <div class="td-single-service-box-2">
                                <div class="td-service-box-2-icon service-icon-number-<?php echo $box_number;?>">

									<?php if ( $service_box['type'] === 'image' ) :
										if ( $service_box['image']['url'] || $service_box['image']['id'] ) :
											?>

                                            <img class="service-image-icon" src="<?php echo $service_box['image']['url']; ?>"
                                                 alt="<?php echo get_post_meta( $service_box['image']['id'], '_wp_attachment_image_alt', true ); ?>">
										<?php endif;
                                    elseif ( ! empty( $service_box['icon'] ) || ! empty( $service_box['selected_icon'] ) ) : ?>
										<?php ThemeDraft_Custom_Icon_Render( $service_box, 'icon', 'selected_icon' ); ?>
									<?php endif; ?>
                                </div>

                                <div class="td-service-box-2-content">
									<?php if(!empty($service_box['button_link']['url'])) : ?>
                                        <a href="<?php echo $service_box['button_link']['url'];?>" class="td-service-box-2-title" <?php echo $target . $nofollow ;?>><?php echo $service_box['title'];?></a>
									<?php else : ?>
                                        <h4 class="td-service-box-2-title"><?php echo $service_box['title'];?></h4>
									<?php endif; ?>

									<?php echo $service_box['desc'];?>
                                </div>

                                <div class="service-box-2-button-wrapper">
                                    <a href="<?php echo $service_box['button_link']['url'];?>" class="td_text_button td-service-box-2-button"><?php echo $service_box['button_text'];?></a>
                                </div>
                            </div>
                        </div>

					<?php    }
				} ?>
            </div>

            <style>
                <?php
					if($settings['service_boxes']){
						$box_number = 0;
						foreach ($settings['service_boxes'] as $service_box){
							$box_number++; ?>

                .td-service-box-2-icon.service-icon-number-<?php echo $box_number;?>{
                    background-color: <?php echo $service_box['icon_bg_color'];?>;
                }

                .td-service-box-2-icon.service-icon-number-<?php echo $box_number;?> i{
                    color: <?php echo $service_box['icon_color'];?>;
                }

                .td-service-box-2-icon.service-icon-number-<?php echo $box_number;?> svg{
                    fill: <?php echo $service_box['icon_color'];?>;
                }
                <?php

					}
				}
			?>
            </style>
        </div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Service_Box_Two_Widget );