<?php
namespace Elementor;

class ThemeDraft_Service_Box_Four_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_service_box_four';
	}

	public function get_title() {
		return esc_html__( 'Service Box Four', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-suitcase';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'service_box_settings',
			[
				'label' => esc_html__( 'Service Boxes', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();


		$repeater->add_control(
			'image',
			[
				'label'     => __( 'Image', 'themedraft-core' ),
				'type'      => Controls_Manager::MEDIA,
				'default'   => [
					'url' => Utils::get_placeholder_image_src(),
				],
				
				'dynamic'   => [
					'active' => true,
				]
			]
		);

		$repeater->add_control(
			'title',
			[
				'label'       => __( 'Box Title', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXTAREA,
				'rows'        => 5,
				'default'     => __( 'Awarded service', 'themedraft-core' ),
				'placeholder' => __( 'Type box title here.', 'themedraft-core' ),
			]
		);

		$repeater->add_control(
			'title_link',
			[
				'label'         => __( 'Details Url', 'themedraft-core' ),
				'type'          => Controls_Manager::URL,
				'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
				'show_external' => true,
				'default'       => [
					'url'         => '',
					'is_external' => false,
					'nofollow'    => false,
				],
			]
		);

		$repeater->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'themedraft-core' ),
				'type'        => Controls_Manager::WYSIWYG,
				'default'     => __( 'There are many variations of passages of Lorem available and but the majority have suffered alteration in some form.', 'themedraft-core' ),
				'label_block' => true,
			]
		);

		$repeater->add_control(
		    'bg_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		    ]
		);


		$this->add_control(
			'service_boxes',
			[
				'label'       => __('Service List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'title'        => __('Full diagnostics', 'themedraft-core'),
						'desc' => __('There are many variations of passages of Lorem available and but the majority have suffered alteration in some form.', 'themedraft-core'),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);

		$this->add_control(
			'desktop_column',
			[
				'label'   => __( 'Desktop Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-lg-4',
				'options' => [
					'col-lg-12' => __( '1 Column', 'themedraft-core' ),
					'col-lg-6'  => __( '2 Column', 'themedraft-core' ),
					'col-lg-4'  => __( '3 Column', 'themedraft-core' ),
					'col-lg-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'tab_column',
			[
				'label'   => __( 'Tablet Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 'col-md-6',
				'options' => [
					'col-md-12' => __( '1 Column', 'themedraft-core' ),
					'col-md-6'  => __( '2 Column', 'themedraft-core' ),
					'col-md-4'  => __( '3 Column', 'themedraft-core' ),
					'col-md-3'  => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'service_title_style',
			[
				'label' => esc_html__( 'Title', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-service-box-4-title',
			]
		);

		$this->add_control(
			'title_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-box-4-title' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-single-service-box-4:hover .td-service-box-4-title' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();


		$this->start_controls_section(
			'service_text_style',
			[
				'label' => esc_html__( 'Text', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'text_typo',
				'label' => __( 'Typography', 'themedraft-core' ),
				'selector' => '{{WRAPPER}} .td-service-box-4-content',
			]
		);

		$this->add_control(
			'text_color',
			[
				'label'       => esc_html__('Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-service-box-4-content' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'text_hover_color',
			[
				'label'       => esc_html__('Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-single-service-box-4:hover .td-service-box-4-content' => 'color: {{VALUE}};',
				],
			]
		);
		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

		<div class="td-service-box-4-wrapper">
			<div class="row">
				<?php if($settings['service_boxes']){
					foreach ($settings['service_boxes'] as $service_box){
						$target   = $service_box['title_link']['is_external'] ? ' target="_blank"' : '';
						$nofollow = $service_box['title_link']['nofollow'] ? ' rel="nofollow"' : '';
						?>

						<div class="<?php echo $settings['desktop_column'] . ' ' . $settings['tab_column'];?>">
							<div class="td-single-service-box-4">
                                <div class="td-service-4-image-wrapper">
                                    <div class="td-service-4-image-bg" style="background-color: <?php echo $service_box['bg_color'];?>"></div>
								<div class="td-service-4-image" style="background-image: url(<?php echo $service_box['image']['url'];?>)"></div>
                                </div>

								<div class="td-service-box-4-content">
									<?php if(!empty($service_box['title_link']['url'])) : ?>
										<a href="<?php echo $service_box['title_link']['url'];?>" class="td-service-box-4-title" <?php echo $target . $nofollow ;?>><?php echo $service_box['title'];?></a>
									<?php else : ?>
										<h4 class="td-service-box-4-title"><?php echo $service_box['title'];?></h4>
									<?php endif; ?>

									<?php echo $service_box['desc'];?>
								</div>
							</div>
						</div>

					<?php    }
				} ?>
			</div>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Service_Box_Four_Widget );