<?php
namespace Elementor;

class ThemeDraft_Service_Box_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_text_with_title';
	}

	public function get_title() {
		return esc_html__( 'Service Box', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-suitcase';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'service_box_settings',
			[
				'label' => esc_html__( 'Service Box', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image',
			[
				'label'       => __( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_control(
		    'title',
		    [
		        'label'       => __( 'Title', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXTAREA,
		        'rows'        => 5,
		        'default'     => __( 'Type title here', 'themedraft-core' ),
		    ]
		);

		$this->add_control(
		    'desc',
		    [
		        'label'       => __( 'Decription', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => __( 'There are many variations of passages of Lorem Ipsum, but the majority have suffered alteration in some form.', 'themedraft-core' ),
		        'label_block' => true,
		    ]
		);

		$this->add_control(
		    'link',
		    [
		        'label'         => __( 'Box Link', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		    ]
		);

		$this->add_control(
		    'button_text',
		    [
		        'label'       => __( 'Button Text', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => __( 'Read More', 'themedraft-core' ),
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'service_box_style',
		    [
		        'label' => esc_html__( 'Image', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_responsive_control(
			'image_max_width',
			[
				'label' => __( 'Image Max Width', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 200,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-service-image' => 'max-width:{{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
		    'image_top_position',
		    [
		        'label' => __( 'Image Position From Top', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['%', 'px'],
		        'range' => [
			        '%' => [
				        'min' => -100,
				        'max' => 100,
			        ],

		            'px' => [
		                'min' => -500,
		                'max' => 500,
		            ],

		        ],
		        'devices' => [ 'desktop', 'tablet', 'mobile' ],

		        'selectors' => [
		            '{{WRAPPER}} .td-service-image' => 'top: {{SIZE}}{{UNIT}};',
		        ],
		    ]
		);

		$this->add_responsive_control(
			'image_left_position',
			[
				'label' => __( 'Image Position From Left', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['%', 'px'],
				'range' => [
					'%' => [
						'min' => -100,
						'max' => 100,
					],

					'px' => [
						'min' => -500,
						'max' => 500,
					],

				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} .td-service-image' => 'transform: translateX({{SIZE}}{{UNIT}});-webkit-transform: translateX({{SIZE}}{{UNIT}});-ms-transform: translateX({{SIZE}}{{UNIT}});',
				],
			]
		);

		$this->add_control(
		    'image_bg_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-service-image-bg' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'title_style',
		    [
		        'label' => esc_html__( 'Title', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_group_control(
		    Group_Control_Typography::get_type(),
		    [
		        'name' => 'title_typography',
		        'label' => __( 'Typography', 'themedraft-core' ),
		        'selector' => '{{WRAPPER}} .td-service-title',
		    ]
		);

		$this->add_control(
		    'title_color',
		    [
		        'label'       => esc_html__('Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-service-title' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'title_hover_color',
			[
				'label'       => esc_html__('Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} a .td-service-title:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();


		// Button Style
		$this->start_controls_section(
			'service_button_style',
			[
				'label' => esc_html__( 'Button', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);


		$this->start_controls_tabs('td_button_style_tabs');

		//Default style start
		$this->start_controls_tab(
			'btn_normal_style',
			[
				'label' => esc_html__('Normal', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_normal_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-service-box-button .td_button' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_normal_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-service-box-button .td_button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_normal_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-service-box-button .td_button' => 'border-color: {{VALUE}};',
				],
			]
		);


		$this->end_controls_tab();//Default style tab end

		//Hover style tab start
		$this->start_controls_tab(
			'btn_hover_style',
			[
				'label' => esc_html__('Hover', 'themedraft-core'),
			]
		);

		$this->add_control(
			'button_hover_bg',
			[
				'label'     => esc_html__('Background Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-service-box-button .td_button:hover' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_color',
			[
				'label'     => esc_html__('Text Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-service-box-button .td_button:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_hover_border_color',
			[
				'label'     => esc_html__('Border Color', 'themedraft-core'),
				'type'      => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .td-service-box-button .td_button:hover' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tabs();//Hover style tab end

		$this->end_controls_section();


	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		$target   = $settings['link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';
		?>

		<div class="td-service-box-wrapper">
			<div class="td-service-top">
				<div class="td-service-image">
					<img src="<?php echo $settings['image']['url']; ?>"
					     alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">
				</div>

				<div class="td-service-image-bg"></div>
			</div>

			<div class="td-service-box-desc">

                <?php if(!empty($settings['link']['url'])) : ?>
                    <a class="td-title-link" href="<?php echo $settings['link']['url'];?>" <?php echo $target . $nofollow ;?>>
                        <h4 class="td-service-title"><?php echo $settings['title'];?></h4>
                    </a>
                <?php else : ?>
                    <h4 class="td-service-title"><?php echo $settings['title'];?></h4>
                <?php endif; ?>
				<?php echo $settings['desc'];?>
			</div>

            <div class="td-service-box-button">
                <a href="<?php echo $settings['link']['url'];?>" class="td_button" <?php echo $target . $nofollow ;?>><?php echo $settings['button_text'];?></a>
            </div>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Service_Box_Widget );