<?php
namespace Elementor;

class ThemeDraft_Skill_Bar_Line_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_skill_bar_line';
	}

	public function get_title() {
		return esc_html__( 'Skill Bar Line', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-skill-bar';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'add_skills_settings',
			[
				'label' => esc_html__( 'Skills', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
		    'title',
		    [
		        'label'       => __('Title', 'themedraft-core'),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => __('Pet Training', 'themedraft-core'),
		        'label_block' => true,
		    ]
		);

		$repeater->add_control(
		    'percent',
		    [
		        'label' => __( 'Percentage', 'themedraft-core' ),
		        'type' => Controls_Manager::SLIDER,
		        'size_units' => ['%'],
		        'range' => [
		            '%' => [
		                'min' => 0,
		                'max' => 100,
		            ],
		        ],
		        'default' => [
			        'unit' => '%',
			        'size' => 80,
		        ],
		    ]
		);

		$this->add_control(
		    'skills',
		    [
		        'label'       => __('Skill List', 'themedraft-core'),
		        'type'        => Controls_Manager::REPEATER,
		        'fields'      => $repeater->get_controls(),
		        'default'     => [
		            [
		                'title'        => __('Pet Training', 'themedraft-core'),
		                'percent' => 80
		            ],
		        ],
		        'title_field' => '{{{ title }}}',
		    ]
		);

		$this->end_controls_section();


		$this->start_controls_section(
		    'skill_style_options',
		    [
		        'label' => esc_html__( 'Skill Styles', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'bar_bg_color',
		    [
		        'label'       => esc_html__('Background Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-skills-wrapper .skillbar' => 'background-color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'bar_fill_color',
			[
				'label'       => esc_html__('Fill Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-skills-wrapper .count-bar' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

		<div class="td-skills-wrapper">

            <?php
                if($settings['skills']){
                    foreach($settings['skills'] as $skill){ ?>
                        <div class="skillbar" data-percent="<?php echo $skill['percent']['size'];?>%">
                            <div class="skill-title"><?php echo $skill['title'];?></div>
                            <div class="count-bar">
                                <div class="skill-percent-count-wrap"><span class="skill-percent-count"><?php echo $skill['percent']['size'];?></span>%</div>
                            </div>
                        </div>
            <?php
                    }
                }
            ?>
		</div>
		<?php

	}

	//Template
	protected function content_template() { ?>
        <div class="td-skills-wrapper">

            <# if ( settings.skills.length ) { #>
                <# _.each( settings.skills, function( skill ) { #>
                    <div class="skillbar" data-percent="{{skill.percent.size}}%">
                        <div class="skill-title">{{{skill.title}}}</div>
                        <div class="count-bar">
                            <div class="skill-percent-count-wrap"><span class="skill-percent-count">{{{skill.percent.size}}}</span>%</div>
                        </div>
                    </div>
                <# }); #>
            <# } #>
        </div>

        <script>
            (function ($) {
                "use strict";
                $(document).ready(function () {
                    $(".skillbar").each(function() {
                        $(this).appear(function() {
                            $(this).find(".count-bar").animate({
                                width:$(this).attr("data-percent")
                            },3000);
                        });
                    });

                    $(".skill-percent-count").counterUp({
                        delay: 10,
                        time: 3000
                    });
                });
            })(jQuery);
        </script>

<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Skill_Bar_Line_Widget );