<?php
namespace Elementor;
use WP_Query;
class ThemeDraft_Team_Member_Info_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_team_member_info';
	}

	public function get_title() {
		return esc_html__( 'Team Member Info', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-employee-2';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'member_info_option',
			[
				'label' => esc_html__( 'Member Info', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'member_name',
		    [
		        'label'       => __( 'Member Mane', 'themedraft-core' ),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => __( 'Andrue Anderson', 'themedraft-core' ),
		        'placeholder' => __( 'Member name here', 'themedraft-core' ),
			    'label_block' => true
		    ]
		);

		$this->add_control(
			'member_designation',
			[
				'label'       => __( 'Member Designation', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => __( 'Pet Train Master', 'themedraft-core' ),
				'placeholder' => __( 'Member designation here', 'themedraft-core' ),
				'label_block' => true
			]
		);

		$this->add_control(
		    'info_list',
		    [
		        'label'       => __( 'Info List', 'themedraft-core' ),
		        'type'        => Controls_Manager::WYSIWYG,
		        'default'     => __( '<ul>
 	<li><strong>Experience :</strong> 10 Years</li>
 	<li><strong>Experience At :</strong> Pet Training, Pet Caring.</li>
 	<li><strong>Email :</strong> <a href="mailto:youremail@domain.com">youremail@domain.com</a></li>
 	<li><strong>Mobile :</strong> <a href="tel:+8212345678">+820 - 123 - 456 - 78</a></li>
</ul>', 'themedraft-core' ),
		        'description' => __( 'Create an unordered list here. And use bold ( B )  for bold text.', 'themedraft-core' ),
		        'label_block' => true,
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'member_social_option',
			[
				'label' => esc_html__( 'Member Social', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'selected_member',
			[
				'label'       => esc_html__('Select Member', 'themedraft-core'),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => themedraft_team_member_list(),
				'description' => esc_html__('Select Which member\'s icons you want to show. Make sure icons are already added on member single post.', 'themedraft-core'),
			]
		);
		$this->end_controls_section();



	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

		<div class="td-member-info-box">
			<h3 class="member-name"><?php echo $settings['member_name'];?></h3>
			<div class="designation"><?php echo $settings['member_designation'] ?></div>

			<div class="info-list-wrapper td-ul-style">
				<?php echo $settings['info_list'];?>
			</div>

            <div class="td-member-social">
                <ul class="fa4-active td-ul-style td-list-inline">

                    <?php if($settings['selected_member']) : ?>

                    <?php
                    $post_query = new WP_Query(
                        array(
                            'posts_per_page' => 1,
                            'post_type'      => 'valkuta_team',
                            'p'              => $settings['selected_member'],
                        ));

                        while ($post_query->have_posts()) :
                        $post_query->the_post();
                        if (get_post_meta(get_the_ID(), 'valkuta_team_meta', true)) {
                            $teamMeta = get_post_meta(get_the_ID(), 'valkuta_team_meta', true);
                        } else {
                            $teamMeta = array();
                        }

                        if (array_key_exists('member_social_profile', $teamMeta)) {
                            $memberSocial = $teamMeta['member_social_profile'];
                        } else {
                            $memberSocial = array();
                        }

                        ?>
	                        <?php
	                        foreach ( $memberSocial as $social ) {
		                        $icon = $social['site_icon'];
		                        $url  = $social['site_url']; ?>
                                <li>
                                    <a target="_blank" href="<?php echo esc_url($url); ?>">
                                        <i class="<?php echo $icon; ?>"></i>
                                    </a>
                                </li>
		                        <?php
	                        }
	                        ?>
                    <?php
                    endwhile;
                    wp_reset_query();

                    endif;
                    ?>
                </ul>
            </div>
		</div>

		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Team_Member_Info_Widget );