<?php
namespace Elementor;

class ThemeDraft_Team_Member_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_team_member';
	}

	public function get_title() {
		return esc_html__( 'Team Member', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-team-3';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'team_member_options',
			[
				'label' => esc_html__( 'Team Member', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
		    'team_layout',
		    [
		        'label'   => __( 'Layout', 'themedraft-core' ),
		        'type'    => Controls_Manager::SELECT,
		        'default' => 'td-team-layout-1',
		        'options' => [
		            'td-team-layout-1' => __( 'Layout 1', 'themedraft-core' ),
		            'td-team-layout-2'  => __( 'Layout 2', 'themedraft-core' ),
		        ],
		    ]
		);

		$repeater = new Repeater();

		$repeater->add_control(
		    'member_name',
		    [
		        'label'       => __('Name', 'themedraft-core'),
		        'type'        => Controls_Manager::TEXT,
		        'default'     => __('Rehnu Johnson', 'themedraft-core'),
		        'label_block' => true,
		    ]
		);


		$repeater->add_control(
		    'member_designation',
		    [
		        'label'   => __('Designation', 'themedraft-core'),
		        'type'    => Controls_Manager::TEXT,
		        'default' => __('Pet Trainer', 'themedraft-core'),
		        'label_block' => true,
		    ]
		);

		$repeater->add_control(
		    'member_image',
		    [
		        'label'       => __( 'Image', 'themedraft-core' ),
		        'type'        => Controls_Manager::MEDIA,
		        'label_block' => true,
		        'default'     => [
		            'url' => Utils::get_placeholder_image_src(),
		        ],
		    ]
		);

		$repeater->add_control(
		    'member_details',
		    [
		        'label'         => __( 'Details Link', 'themedraft-core' ),
		        'type'          => Controls_Manager::URL,
		        'placeholder'   => __( 'https://your-link.com', 'themedraft-core' ),
		        'show_external' => true,
		        'default'       => [
		            'url'         => '',
		            'is_external' => false,
		            'nofollow'    => false,
		        ],
		    ]
		);



		$this->add_control(
		    'all_members',
		    [
		        'label'       => __('Members List', 'themedraft-core'),
		        'type'        => Controls_Manager::REPEATER,
		        'fields'      => $repeater->get_controls(),
		        'default'     => [
		            [
		                'member_name'        => __('Rehnu Johnson', 'themedraft-core'),
		                'member_designation' => __('Pet Trainer', 'themedraft-core'),
		            ],
		        ],
		        'title_field' => '{{{ member_name }}}',
		    ]
		);

		$this->end_controls_section();

		$this->start_controls_section(
		    'team_style_options',
		    [
		        'label' => esc_html__( 'Colors', 'themedraft-core' ),
		        'tab'   => Controls_Manager::TAB_STYLE,
		    ]
		);

		$this->add_control(
		    'name_color',
		    [
		        'label'       => esc_html__('Name Color', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-member-name' => 'color: {{VALUE}};',
		        ],
		    ]
		);

		$this->add_control(
			'name_hover_color',
			[
				'label'       => esc_html__('Name Hover Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-member-name:hover' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'designation_color',
			[
				'label'       => esc_html__('Designation Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-member-designation' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
		    'plus_icon_bg',
		    [
		        'label'       => esc_html__('Plus Icon Background', 'themedraft-core'),
		        'type'        => Controls_Manager::COLOR,
		        'selectors'   => [
		            '{{WRAPPER}} .td-team-layout-2 .td-team-member-image .td-member-details-link' => 'background-color: {{VALUE}};',
		        ],
                'condition' => [
                    'team_layout' => 'td-team-layout-2',
                ],
		    ]
		);

		$this->add_control(
			'bg_shape_color',
			[
				'label'       => esc_html__('Image Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-team-layout-2 .td-team-member-image:after' => 'background-color: {{VALUE}};',
				],
				'condition' => [
					'team_layout' => 'td-team-layout-2',
				],
			]
		);

		$this->end_controls_section();


	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

        <div class="row <?php echo $settings['team_layout'];?>">

	        <?php if($settings['all_members']){
	        	foreach ($settings['all_members'] as $member){
	        	    $target   = $member['member_details']['is_external'] ? ' target="_blank"' : '';
	        	    $nofollow = $member['member_details']['nofollow'] ? ' rel="nofollow"' : '';
	        	    ?>

			        <div class="col-lg-4 col-md-6">
				        <div class="td-single-team-member">
					        <div class="td-team-member-image-wrapper">

                                <?php if(!empty($member['member_details']['url']) && $settings['team_layout'] == 'td-team-layout-1') :  ?>
						        <a class="td-team-member-img-link" href="<?php echo $member['member_details']['url'];?>" <?php echo $target . $nofollow ;?>>
                                <?php endif; ?>
							        <div class="td-team-member-image" style="background-image: url(<?php echo esc_url($member['member_image']['url']);?>)">
                                        <?php if($settings['team_layout'] == 'td-team-layout-2') :?>
                                            <a href="<?php echo $member['member_details']['url'];?>" class="td-member-details-link">+</a>
                                        <?php endif;?>
                                    </div>
			                    <?php if(!empty($member['member_details']['url']) && $settings['team_layout'] == 'td-team-layout-1') :  ?>
						        </a>
					            <?php endif; ?>
					        </div>

			                <?php if(!empty($member['member_details']['url'])) :  ?>
                            <a href="<?php echo $member['member_details']['url'];?>" class="td-member-name" <?php echo $target . $nofollow ;?>><?php echo $member['member_name'];?></a>
                            <?php else : ?>
                            <h4 class="td-member-name"><?php echo $member['member_name'];?></h4>
                            <?php endif;?>

					        <span class="td-member-designation"><?php echo $member['member_designation'];?></span>
				        </div>
			        </div>
		    <?php    }
	        } ?>
        </div>
		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Team_Member_Widget );