<?php
namespace Elementor;

class ThemeDraft_Testimonial_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_testimonial';
	}

	public function get_title() {
		return esc_html__( 'Testimonial', 'themedraft-core' );
	}

	public function get_icon() {

		return 'flaticon-business-medal-1';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'testimonial_settings',
			[
				'label' => esc_html__( 'Testimonials', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'author_name',
			[
				'label'       => __('Author Name', 'themedraft-core'),
				'type'        => Controls_Manager::TEXT,
				'default'     => __('Md Nadim Khan', 'themedraft-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'designation',
			[
				'label'       => __('Designation', 'themedraft-core'),
				'type'        => Controls_Manager::TEXT,
				'default'     => __('Dog Lover', 'themedraft-core'),
				'label_block' => true,
			]
		);

		$repeater->add_control(
			'photo',
			[
				'label'       => __( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$repeater->add_control(
			'testimonial_text',
			[
				'label'   => __('Description', 'themedraft-core'),
				'type'    => Controls_Manager::WYSIWYG,
				'default' => __('Really awesome author. He helped me when I was stuck at some crazy stuff. I can\'t believe how often he was available to help with huge time difference. I highly recommend this theme.', 'themedraft-core'),
			]
		);

		$this->add_control(
			'testimonials',
			[
				'label'       => __('Testimonial List', 'themedraft-core'),
				'type'        => Controls_Manager::REPEATER,
				'fields'      => $repeater->get_controls(),
				'default'     => [
					[
						'author_name'        => __('Md Nadim Khan', 'themedraft-core'),
						'designation'        => __('Dog Lover', 'themedraft-core'),
						'testimonial_text' => __('Really awesome author. He helped me when I was stuck at some crazy stuff. I can\'t believe how often he was available to help with huge time difference. I highly recommend this theme.', 'themedraft-core'),
					],
				],
				'title_field' => '{{{ author_name }}}',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'slider_options',
			[
				'label' => esc_html__( 'Slider Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label'       => __( 'Autoplay', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'no',
			]
		);

		$this->add_control(
			'autoplay_interval',
			[
				'label'       => __( 'Autoplay Interval', 'themedraft-core' ),
				'type'        => Controls_Manager::SELECT,
				'show_label'  => true,
				'label_block' => false,
				'options'     => [
					'2000'  => __( '2 seconds', 'themedraft-core' ),
					'3000'  => __( '3 seconds', 'themedraft-core' ),
					'4000'  => __( '4 seconds', 'themedraft-core' ),
					'5000'  => __( '5 seconds', 'themedraft-core' ),
					'6000'  => __( '6 seconds', 'themedraft-core' ),
					'7000'  => __( '7 seconds', 'themedraft-core' ),
					'8000'  => __( '8 seconds', 'themedraft-core' ),
					'9000'  => __( '9 seconds', 'themedraft-core' ),
					'10000' => __( '10 seconds', 'themedraft-core' ),
				],
				'default'     => '4000',
				'condition'   => [
					'autoplay' => 'yes',
				],
			]
		);

		$this->add_control(
			'nav_dots',
			[
				'label'       => __( 'Navigation Dots', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'no',
			]
		);

		$this->add_control(
			'infinity_loop',
			[
				'label'       => __( 'Loop', 'themedraft-core' ),
				'type'        => Controls_Manager::SWITCHER,
				'show_label'  => true,
				'label_block' => false,
				'default'     => 'yes',
			]
		);

		$this->add_control(
			'desktop_count',
			[
				'label'   => __( 'Desktop Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 1,
				'options' => [
					1  => __( '1 Column', 'themedraft-core' ),
					2  => __( '2 Column', 'themedraft-core' ),
					3  => __( '3 Column', 'themedraft-core' ),
					4  => __( '4 Column', 'themedraft-core' ),
					5  => __( '5 Column', 'themedraft-core' ),
					6  => __( '6 Column', 'themedraft-core' ),
					7  => __( '7 Column', 'themedraft-core' ),
					8  => __( '8 Column', 'themedraft-core' ),
					9  => __( '9 Column', 'themedraft-core' ),
					10 => __( '10 Column', 'themedraft-core' ),
					11 => __( '11 Column', 'themedraft-core' ),
					12 => __( '12 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'tab_count',
			[
				'label'   => __( 'Tablet Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 2,
				'options' => [
					1  => __( '1 Column', 'themedraft-core' ),
					2  => __( '2 Column', 'themedraft-core' ),
					3  => __( '3 Column', 'themedraft-core' ),
					4  => __( '4 Column', 'themedraft-core' ),
					5  => __( '5 Column', 'themedraft-core' ),
					6  => __( '6 Column', 'themedraft-core' ),
					7  => __( '7 Column', 'themedraft-core' ),
					8  => __( '8 Column', 'themedraft-core' ),
					9  => __( '9 Column', 'themedraft-core' ),
					10 => __( '10 Column', 'themedraft-core' ),
					11 => __( '11 Column', 'themedraft-core' ),
					12 => __( '12 Column', 'themedraft-core' ),
				],
			]
		);

		$this->add_control(
			'mobile_count',
			[
				'label'   => __( 'Mobile Column', 'themedraft-core' ),
				'type'    => Controls_Manager::SELECT,
				'default' => 1,
				'options' => [
					1 => __( '1 Column', 'themedraft-core' ),
					2 => __( '2 Column', 'themedraft-core' ),
					3 => __( '3 Column', 'themedraft-core' ),
					4 => __( '4 Column', 'themedraft-core' ),
				],
			]
		);

		$this->end_controls_section();
	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		if(is_rtl()){
			$slide_dir = 'dir="ltr"';
		}else{
			$slide_dir = '';
		}
		?>

		<div class="td-testimonial-slide-wrapper">

			<div <?php echo $slide_dir;?> class="td-testimonial-slider-content td-testimonial-slider">
				<?php if($settings['testimonials']){
					foreach ($settings['testimonials'] as $testimonial){
						?>
                        <div class="td-testimonial-item-container">
                            <div class="td-testimonial-slide-item">
                                <div class="quote-icon">
                                    <i class="flaticon-business-quote-left"></i>
                                </div>
                                <div class="testimonial-text">
                                    <?php echo wp_kses_post($testimonial['testimonial_text']);?>
                                </div>

                                <div class="person-details">
                                    <img class="testimonial-author-image" src="<?php echo esc_url($testimonial['photo']['url']);?>" alt="<?php echo get_post_meta( $testimonial['photo']['id'], '_wp_attachment_image_alt', true ); ?>">
                                    <h4 class="name"><?php echo $testimonial['author_name'];?></h4>
                                    <p class="designation"><?php echo $testimonial['designation'];?></p>
                                </div>
                            </div>
                        </div>

						<?php
					}
				} ?>
			</div>

			<script>
                (function ($) {
                    "use strict";
                    jQuery(document).ready(function () {
                        jQuery(".td-testimonial-slider").slick({
                            slidesToShow: <?php echo json_encode( $settings['desktop_count'] )?>,
                            autoplay: <?php echo json_encode( $settings['autoplay'] == 'yes' ? true : false ); ?>,
                            autoplaySpeed: <?php echo json_encode( $settings['autoplay_interval'] )?>, //interval
                            speed: 1500, // slide speed
                            dots: <?php echo json_encode( $settings['nav_dots'] == 'yes' ? true : false ); ?>,
                            arrows: false,
                            infinite: <?php echo json_encode( $settings['infinity_loop'] == 'yes' ? true : false ); ?>,
                            pauseOnHover: false,
                            centerMode: false,
                            responsive: [
                                {
                                    breakpoint: 1025,
                                    settings: {
                                        slidesToShow: <?php echo json_encode( $settings['tab_count'] )?>, //768-991
                                        dots: false,
                                    }
                                },

                                {
                                    breakpoint: 992,
                                    settings: {
                                        slidesToShow: <?php echo json_encode( $settings['tab_count'] )?>, //768-991
                                        dots: false,
                                    }
                                },
                                {
                                    breakpoint: 768,
                                    settings: {
                                        slidesToShow: <?php echo json_encode( $settings['mobile_count'] )?>, // 0 -767
                                        dots: false,
                                    }
                                }
                            ]
                        });
                    });
                })(jQuery);
			</script>
		</div>

		<?php

	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Testimonial_Widget );
