<?php
namespace Elementor;

class ThemeDraft_Video_Popup_Widget extends Widget_Base {

	public function get_name() {

		return 'themedraft_video_popup';
	}

	public function get_title() {
		return esc_html__( 'Video Popup', 'themedraft-core' );
	}

	public function get_icon() {

		return 'eicon-youtube';
	}

	public function get_categories() {
		return [ 'valkuta_elements' ];
	}


	protected function register_controls() {

		//Content tab start
		$this->start_controls_section(
			'video_popup_settings',
			[
				'label' => esc_html__( 'Video Popup Options', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'image',
			[
				'label'       => __( 'Image', 'themedraft-core' ),
				'type'        => Controls_Manager::MEDIA,
				'label_block' => true,
				'default'     => [
					'url' => Utils::get_placeholder_image_src(),
				],
			]
		);

		$this->add_responsive_control(
			'image_wrapper_width',
			[
				'label' => __( 'Image Wrapper Width ( % )', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['%'],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 150,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'desktop_default' => [
					'size' => 100,
					'unit' => '%',
				],
				'tablet_default' => [
					'size' => 100,
					'unit' => '%',
				],
				'mobile_default' => [
					'size' => 100,
					'unit' => '%',
				],
				'selectors' => [
					'{{WRAPPER}} .td-video-popup-image' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);


		$this->add_control(
			'video_url',
			[
				'label'       => __( 'Video Url', 'themedraft-core' ),
				'type'        => Controls_Manager::TEXT,
				'label_block'        => true,
				'default'     => __( 'https://vimeo.com/100902001', 'themedraft-core' ),
				'placeholder' => __( 'https://your-link.com', 'themedraft-core' ),
			]
		);



		$this->add_responsive_control(
			'button_size',
			[
				'label' => __( 'Button Size', 'themedraft-core' ),
				'type' => Controls_Manager::SLIDER,
				'size_units' => ['px'],
				'range' => [
					'px' => [
						'min' => 50,
						'max' => 200,
					],
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'selectors' => [
					'{{WRAPPER}} ..td-video-popup-wrapper .td_video_button:before, {{WRAPPER}} ..td-video-popup-wrapper .td_video_button:after' => 'height: {{SIZE}}{{UNIT}};width: {{SIZE}}{{UNIT}};',
				],

				'condition' => [
					'video_url!' => '',
				],
			]
		);

		$this->end_controls_section();


		//Style tab start
		$this->start_controls_section(
			'video_popup_style',
			[
				'label' => esc_html__( 'Colors', 'themedraft-core' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
		);


		$this->add_control(
			'button_bg_color',
			[
				'label'       => esc_html__('Button Background Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-video-popup-wrapper .td_video_button:before, {{WRAPPER}} .td-video-popup-wrapper .td_video_button:after' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'button_icon_color',
			[
				'label'       => esc_html__('Button Icon Color', 'themedraft-core'),
				'type'        => Controls_Manager::COLOR,
				'selectors'   => [
					'{{WRAPPER}} .td-video-popup-wrapper .td_video_button i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_section();


	}

	//Render
	protected function render() {
		$settings = $this->get_settings_for_display();
		?>

        <div class="td-video-popup-wrapper">
            <div class="td-video-popup-image">
                <img src="<?php echo esc_url($settings['image']['url'])?>" alt="<?php echo get_post_meta( $settings['image']['id'], '_wp_attachment_image_alt', true ); ?>">
				<?php if($settings['video_url']) :?>
                    <a href="<?php echo esc_url($settings['video_url']);?>" class="td_video_button mfp-iframe">
                        <i class="fa fa-play"></i>
                    </a>
				<?php endif; ?>
            </div>
        </div>
        <script>
            jQuery(document).ready(function ($) {

                $(".td_video_button").magnificPopup({
                    type: 'video'
                });
            });
        </script>

		<?php

	}

	//Template
	protected function content_template() { ?>

        <div class="td-video-popup-wrapper">
            <div class="td-video-popup-image">
                <img src="{{{settings.image.url}}}" alt="">
                <# if ( settings.video_url ) { #>
                <a href="{{{settings.video_url}}}" class="td_video_button mfp-iframe">
                    <i class="fa fa-play"></i>
                </a>
                <# } #>
            </div>
        </div>
        <script>
            jQuery(document).ready(function ($) {

                $(".td_video_button").magnificPopup({
                    type: 'video'
                });
            });
        </script>

		<?php
	}
}

Plugin::instance()->widgets_manager->register( new ThemeDraft_Video_Popup_Widget );